/*-----------------------------------------------------------------------------*
* Title: CLEANING - LONG TERM FOLLOW_UP (COHORT 2014 & 2015) - CAREGIVER  DATA                          
*                                                                                           
* Description: 	Cleans data for Caregiver Long term Follow-up
* Cohort:		2014 and 2015 								         						 
* Start Date:	08/31/2023 	
* Status:		In progress
* End Data:		09/18/2023																
* Author:		Raaga Akkineni (based on code written by 
*				Bendetta Lerve and Margherita Fornasari)									 						  
*
* Purpose: 		1. Cleans Caregiver dataset
*				2. Creates household and education roster
*				3. Cleand HH roster to match standardized dataset
*				4. Merges clean data with standardized dataset
*
* Input: 		MCF_followup_2022_HH.dta
* Output: 		LTFU_Cohort_2014_2015_NoRoster.dta
*				LTFU_Cohort_2014_2015_Cleaned_HHRoster_long.dta
*				LTFU_Cohort_2014_2015_Cleaned_EducRoster_long.dta
*				LTFU_Cohort_2014_2015_StandardizedDataset.dta
*
*Note: Run "Project_MasterDofile.do" file to set up global macros
*-----------------------------------------------------------------------------*/

version 17
set more off

clear all
clear mata

use "$caregiver_enc/data/MCF_followup_2022_HH.dta"

rename Resp_name_check resp_name_check_1

rename *, lower
/* Error message:
1 new name specified repeatedly in newname
    You requested the name resp_name_check be assigned to 2 existing variables:  Resp_name_check and
    resp_name_check.
	
	possible resolve: rename "resp_name_check" as "resp_name_check_1"
*/

*------------------------------------------------------------------------------*
* 1. Reducing dataset size in terms of variable.            *
*   (Only variables useful for data analysis will be kept)  *
*------------------------------------------------------------------------------*
* Dropping variables used to create the roster during the survey:
* fam_* bam_* used to check if the respondent talked about each member
* m`i'a m`i'b m`i'c: variables created to identify kids to pull in section E
* x_* and y_* used to create e10a, e10b and e10
* v_* used to calculate hh1 (total cost spent on health care)
* d3_b* used to collect information about member's decision to leave the hh


drop fam_? fam_?? bam_? bam_?? 

**drop d3_b*  // to be checked

local i=1
while `i'<24 {

  set more off
  drop m`i'a m`i'b m`i'c

  local i=`i'+1
}


**Record survey year 
gen survey_year = year(today)
/*------------------------------------------------------------------------------
                         **  Cleaning Section A	 **
------------------------------------------------------------------------------*/


* Saving variables in section intro as a local - data pulled from "Cohort2014_2015_LTFU_caregiver_pulldata"
local xlist_intro "hhm_1 hhm_2 hhm_3 hhm_4 hhm_5 hhm_6 hhm_7 hhm_8 hhm_9 hhm_10 hhm_11 hhm_12 hhm_13 hhm_14 hhm_15 hhm_16 hhm_17 hhm_18 hhm_19 hhm_20 hhm_21 hhm_22 hhm_23 hhm_24 hhm_r_1 hhm_r_2 hhm_r_3 hhm_r_4 hhm_r_5 hhm_r_6 hhm_r_7 hhm_r_8 hhm_r_9 hhm_r_10 hhm_r_11 hhm_r_12 hhm_r_13 hhm_r_14 hhm_r_15 hhm_r_16 hhm_r_17 hhm_r_18 hhm_r_19 hhm_r_20 hhm_r_21 hhm_r_22 hhm_r_23 hhm_r_24 index selected_scholar participation"

* Creating a new "cleaned" variables for each variable in local xlist_intro
foreach var of local xlist_intro {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 				// Keeping variable label //
}

* Destring numerical variables
foreach var in selected_scholar_c hhm_r_1_c hhm_r_2_c hhm_r_3_c hhm_r_4_c hhm_r_5_c hhm_r_6_c hhm_r_7_c hhm_r_8_c hhm_r_9_c hhm_r_10_c hhm_r_11_c hhm_r_12_c hhm_r_13_c hhm_r_14_c hhm_r_15_c hhm_r_16_c hhm_r_17_c hhm_r_18_c hhm_r_19_c hhm_r_20_c hhm_r_21_c hhm_r_22_c hhm_r_21_c hhm_r_22_c hhm_r_23_c hhm_r_24_c{
  set more off
  destring `var', replace
}

/* Raaga's notes: not needed as all variables are already in desired format
* Replacing variables with cleaned name 
foreach var in hhm_1_c hhm_2_c hhm_3_c hhm_4_c hhm_5_c hhm_6_c hhm_7_c hhm_8_c hhm_9_c hhm_10_c hhm_11_c hhm_12_c hhm_13_c hhm_14_c hhm_15_c hhm_16_c{
  replace `var' = proper(`var')
}
*/ 

* Creating variable treatment
gen treatment_c=treatment=="Treatment"
order treatment_c, after (treatment)
label def treatment 1 "Treatment" 0 "Control"
label values treatment_c treatment
label var treatment_c "Treatment Status"

* Dropping variables that have been cleaned
foreach var in index selected_scholar participation {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}

* Order variables 
order app_sur app_oth resp_surname resp_othername correct_app, after(participation_c)

/*

Raaga's notes: 
	- Missing: 
		- app_bd_2015
		- 'a3': DOB of respondent, tutor_oth, tutor_phone (replace by tutor_phone1 & tutor_phone2)
		- aa11 (in which county are we?)
		- a10a a10 (in which region/district are we?)
		- a11 a12 a13 a14 a17 a17 a17_check a17a a19 a20
		- current_phone
	- Additional: current_residence, current_hh_dist
	- Note: Varnames (pp_sur app_oth resp_surname resp_othername correct_app) saved as "varname_2015" in standardized dataset
 
*/

* Saving variables in section A as a local 
local xlist_a "app_sur app_oth resp_surname resp_othername correct_app  a1 a2 app_name_check a4 a5 a5a resp_name_check resp_name_check_1 resp_name_check_fail1 current_hh current_care current_care_oth current_care_spouse current_residence current_hh_reg current_hh_dist current_hh_sub current_hh_vil resp_phone1 resp_phone2 tutor_sur tutor_phone1 tutor_phone2 current_hh_boarding aa10 aa12 aa13 aa13_other aa14 aa15 aa16 aa17 aa18 a6 a6_oth a7 a8 a9 a9_oth a15 a16 a16a a16b a16c a16d"


* Creating a new "cleaned" variables for each variable in local xlist_a
foreach var of local xlist_a {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 				// Keeping variable label //
}

* Passing to missing all "others" values 
local xlist_a1 "app_name_check_c resp_name_check_c resp_name_check_fail1_c current_hh_c current_care_c current_care_spouse_c current_hh_reg_c aa10_c aa12_c a6_c a9_c a15_c"
  foreach var of local xlist_a1 {
  recode `var' (88=.m) (99=.m) (97=.m)
}

* Dropping variables that have been cleaned
foreach var of local xlist_a {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}

*rename varnames to match standardized dataset
rename tutor_phone1_c tutor_phone_c

* Current and tutor phone
destring a16_c a16a_c a16b_c resp_phone1_c resp_phone2_c tutor_phone_c tutor_phone2_c, replace
/*------------------------------------------------------------------------------
						** Cleaning Section C **
------------------------------------------------------------------------------*/

/*
Raaga's note: 
	- Missing variable: pov2
	- additional variable: pov12
*/
* Saving variables in section C as a local
local xlist_c "pov1 pov3 c3a pov4 pov5 c5a c5b pov11 pov6 c6a pov7 pov8 pov9 pov10 pov12 app_bank_account"

* Creating a new variables for each variable in local xlist_c
foreach var of local xlist_c {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 				// Keeping variable label //
}

rename app_bank_account_c c12_c			// to match standardized data set	//
/*
Raaga to double check lines 174-174
*/
* Passing to missing all "others" values
foreach var in c3a_c pov4_c{
  set more off
  recode `var' (99=.) (4=.)
}


* Dropping variables that have been cleaned
foreach var of local xlist_c {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
                         **  Cleaning Section I	 **
------------------------------------------------------------------------------*/

/*

Raaga's notes: 
	- Missing: none
	- Additional: none
 
*/

local xlist_i "i1a1 i1a2 i1a3 i2a1 i2a2 i2a3 i20a1 i20a2 i20a3 i3a1 i3a2 i3a3 i21a1 i21a2 i21a3 i4a1 i4a2 i4a3 i5a1 i5a2 i5a3 i6a1 i6a2 i6a3 i7a1 i7a2 i7a3 i8a1 i8a2 i8a3 i9a1 i9a2 i9a3 i10a1 i10a2 i10a3 i11a1 i11a2 i11a3 i12a1 i12a2 i12a3 i13a1 i13a2 i13a3 i14a1 i14a2 i14a3 i15a1 i15a2 i15a3 i22a1 i22a2 i22a3 i16a1 i16a2 i16a3 i17a1 i17a2 i17a3 i18a1 i18a2 i18a3 i23a1 i23a2 i23a3 i24a1 i24a2 i24a3 i19a1 i19a2 i19a3 i25a1 i25a2 i25a3 i26 i27 i28 i29 i30"
foreach var of local xlist_i {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 					// Keeping variable label //
   recode `var'_c (99=.d) (98 =.r) 			
}


** Raaga's addition
* Making i*a1_c to 'NO' if i*a2_c = 0, meaning 0 units of asset
local i = 1
while `i'<26 {

   replace i`i'a1_c =  0 	if i`i'a2_c == 0 
   replace i`i'a2_c = .m 	if i`i'a2_c == 0 
   replace i`i'a2_c = .m 	if i`i'a2_c == 99 | i`i'a2_c == 999
   replace i`i'a3_c = .m 	if i`i'a3_c == 99 | i`i'a3_c == 999 
   
local i=`i'+1
}

* Passing to missing weird values (where respondent confused ixa2 with ixa3, which presents the same value.) 

*FIXMERA so in this cases I would either use the key variable to replace specific observations or or bake the equality condition into the if, so if the ixa3 has the same value as ixa2 I would write: replace ixa2 = . if ixa2 == ixa3 & (ixa3 == 1000000 | ...)


*Residential land
replace i1a2_c = .m if i1a2 ==  3000000 
replace	i1a3_c = .m if i1a3 == -999

*Residential House
replace  i2a2_c = .		if  i2a2 == 1000000 | i2a2 == 2000000 | i2a2 == 3000000
replace  i2a3_c = .		if	i2a3 == 0

*Cultivable land
replace  i3a2_c = .		if  i3a2 == 2000000 | i3a2 == 7000000 

*Tools for agriculture
replace  i4a2_c = .		if  i2a2 == 300000  | i2a2 == 19000  
// i4a2_c = 10,000 but i4a3_c = 5000 			- check 
// i4a2_c = 50,000 but i4a3_c = 40,000			- check

*Goats/sheep 
replace  i6a3_c = .		if	i6a3 == 15

*Chicken/Poultry
replace  i8a2_c = .		if  i8a2 == 110000

*Radio
replace  i9a2_c = .		if  i9a2 == 40000
// i9a2_c = 10000 but i9a3_c = 8000 			- check

*Television
replace  i10a2_c = .		if  i10a2 == 350000 
replace  i10a3_c = .		if	i10a3 == 0

*Video/DVD player 
replace  i11a3_c = .		if	i11a3 == 0 

*Mobile phone
replace  i12a2_c = .		if  i12a2 == 35000
// i4a2_c = 50,000 but i4a3_c = 100,000 		- check
// i4a2_c = 70,000 but i4a3_c = 3,000			- check

*Furniture
replace  i15a2_c = .		if  i15a2 == 45000 | i15a2 == 100000 | i15a2 == 300000 
replace  i15a3_c = .		if	i15a3 == 0

*Bicycle
// i6a2_c = 75,000 but i6a3_c = 40,000 			- check
// i6a2_c = 150,000 but i6a3_c = 80,000			- check

*Furniture - same as 15?? - raaga to check 
replace  i22a2_c = .		if  i22a2 > 50 		& i22a2 != . 
replace  i22a3_c = .		if	i22a3 < 1000	& i22a3 != . 

*Machinery or equipment for business
replace  i23a3_c = .		if	i23a3 == 0

*Stock for business - raaga to check
// replace  i24a2_c = .		if  i24a2 > 50 	& i24a2 != .  
replace  i24a3_c = .		if	i24a3 < 1000	& i24a3 != . 

*other businesses // i25a3_c = 400?? 

*food spend
replace i28_c = . 			if 	i28 == 999
// i28_c = 4 & 6??

*fuel
replace i29_c = . 			if 	i29 == 999

*other services
replace i30_c = . 			if 	i30 == 999


** to be droppped once confirmed

* Dropping variables that have been cleaned
foreach var of local xlist_i {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
                         **  Cleaning Section J	 **
------------------------------------------------------------------------------*/

/*

Raaga's notes: 
	- Missing: none
	- Additional: j2_12 j2_13 j18 j19 i24 i25
	- j13 in this questionnaire recording profit from business - different from standardized data var name 
*/

* Saving variables in section J as a local
local xlist_j "j1 jb1 j2 j2_other_activity j3 j4 j5 j6 j7 j8 j9 j10 j11 j2_2 j2_2_other_activity j2_3 j2_4 j2_5 j2_6 j2_7 j2_8 j2_9 j2_10 j2_11 j12 j13 j2_12 j2_13 j14 j15 j16 j17 j18 j19 i24 i25"

* Creating a new variables for each variable in local xlist_i
foreach var of local xlist_j {
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 					// Keeping variable label //
  
}

* Splitting multiple choices
foreach var in j6_c j2_6_c{					
  split `var', destring
  capture order `var'1 `var'2 `var'3 `var'4 `var'5 `var'6 `var'7 `var'8 `var'9 `var'10 `var'11, after(`var')
  drop `var'
}

* Creating f_j10_c as j10, j11 and j13 are all recording the profit		// FIXMEBL - please check logic 	//
gen f_j10_c = cond(j10_c == j11_c, j10_c, cond(j11_c == j13_c, j11_c, cond(j10_c == j13_c, j10_c, .)))
egen f_j10_c1 = rowmean(j10 j11 j13) if  (j11_c != j13_c) & (j10_c != j13_c) & (j10_c != j11_c) // since stata would not let me replace directly, had to use egen.
replace f_j10_c =  f_j10_c1 if  (j11_c != j13_c) & (j10_c != j13_c) & (j10_c != j11_c)
drop f_j10_c1 

* Similarly, for business 2 - only one instance recorded
gen f_j2_10_c = cond(j2_10_c == j2_11_c, j2_10_c, cond(j2_11_c == j2_13_c, j2_11_c, cond(j2_10_c == j2_13_c, j2_10_c, .)))

drop j10_c j11_c j13_c j2_10_c j2_11_c j2_13_c

* Cleaning money values and passing to missing all "others" values
foreach var in f_j10_c f_j2_10_c {
  recode `var' (99=.m) (98 = .m) (-888 = .m)
  replace `var'= .m if `var'<1000 & `var'!=0 

}

* Dropping variables with no observations
drop j2_2_other_activity_c


* Dropping variables that have been cleaned
foreach var of local xlist_j {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}

* Label var
foreach var in j6_c1 j6_c2 j6_c3 j6_c4 j6_c5 j6_c6 j6_c7 j6_c8 j6_c9 j6_c10 j6_c11 j2_6_c1 j2_6_c2 j2_6_c3 {
   label var `var' "Name of the hh member working with you"  
}

* Re-ordering var
order j6_c1 j6_c2 j6_c3, after (j5_c)
order j2_6_c1 j2_6_c2 j2_6_c3, after (j2_5_c)

*rename to match standardized dataset 
rename j12_c j11_c
rename j14_c j12_c
rename j15_c j13_c
rename j16_c j14_c
rename j17_c j15_c
rename j18_c j16_c
rename j19_c j17_c



/*------------------------------------------------------------------------------
                         **  Cleaning Section K	 **
------------------------------------------------------------------------------*/

/*
Raaga's notes: 
	- Missing: none
	- Additional: none
*/


* Saving variables in section K as a local
local xlist_k "k1 k2a k2b k3a k3b k4a k4b k5a k5b k6a k6b k7a k7b k8a k8b k9a k9b k10a k10b k11a k11b k12a k12b k13a k13b k14a k14b k15a k15b k16a k16b k17a k17b"

* Creating a new variables for each variable in local xlist_k
foreach var of local xlist_k {
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 					// Keeping variable label //
}


* Dropping variables that have been cleaned
foreach var of local xlist_k {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}




/*------------------------------------------------------------------------------
                         **  Cleaning Section M	 **
------------------------------------------------------------------------------*/
/*

Raaga's notes: 
	- Missing: m30b, m24_oth
	- Additional: none
	- updated variables: m1 -> m1_new, m4 -> m4_new, m26 -> m26_new
*/

* Saving variables in section M as a local
local xlist_m "m1_new m2 ma3 m3 m4_new m5 ma5 m6 m7 m8 ma8 m9 m10 m11 ma11 m12 m13 m14 m15 ma15 m16 u1 m17 m17_oth m18 m19 m20 m20_oth m21 m22 m23 m24 m25 m26_new m27 m28 m29 m30 m31 m32 m33 m33_oth m33a m34 m34_oth m35 m36 m36a m37 m37a m38 m38a m38a_oth m39 m39a m39a_oth"

* Creating a new variables for each variable in local xlist_m
foreach var of local xlist_m {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' // Keeping variable label //
}
	
* removing variables with no observations
drop m33_oth_c

* cooperative, credit union or savings association (SACCO, Village Savings and Loan)
replace m4_new_c = 0	if m5 == 0
replace m5_c = .		if m5 == 0

replace ma3_c = 1		if m3 == 0				// logic: if money left to be paid back == 0, implies borrowed money has been paid back
replace m3_c = .		if m3 == 0  

* Bank or Microfinance Institution or NGO (including Brac)
replace ma5_c = 1		if m6 == 0
replace m6_c = . 		if m6 == 0

* Shopkeeper
replace m10_c = 0		if m11 == 0
replace m11_c = . 		if m11 == 0

* other sources 
replace m13_c = 0		if m15 == 0
replace m15_c = . 		if m15 == 0

* savings 
replace m23 = 0 		if m25 == 0 
replace m25 = . 		if m25 == 0
* replace m23 = 0 		if m25 == 98 or m25 == 99  
* replace m25 = . 		if m25 == 98 or m25 == 99 

* Passing to missing weird values
replace m14_c = "" 		if m14 ==  "1000000"

* Splitting multiple choices
foreach var in m17_c m19_c m20_c m34_c m33a_c m35_c{
  set more off
  split `var', destring
  *recode (88=.)
  capture order `var'1 `var'2 `var'3 `var'4 `var'5 `var'6 after (`var') 
  drop  `var'				
}


* Label var and recode 
foreach var in m17_c1 m17_c2 m17_c3 m17_c4 m17_c5 {
   label var `var' "What are the main purposes for borrowing this money? Think about the money you borrowed from ALL sources we discussed."
}

foreach var in m19_c1 m19_c2 {
   label var `var' "Select the household member(s) that borrowed money in the past 12 months."
}

foreach var in m20_c1 m20_c2 m20_c3 {
   label var `var' "Who did they borrow from? "
}

foreach var in m34_c1 m34_c2 m34_c3 m34_c4 m34_c5 {
   label var `var' "What is the main purpose for their savings?"
}

foreach var in m33a_c1 m33a_c2 m33a_c3  {
   label var `var' "Who in the household has a bank account?"
}

foreach var in m35_c1 m35_c2 m35_c3 m35_c4		{
   label var `var' "Who in household has a bank account?"
}

* Re-order var
order m17_c1 m17_c2 m17_c3 m17_c4 m17_c5, after (m16_c)
order m19_c1 m19_c2, after (m18_c)
order m20_c1 m20_c2 m20_c3 , after (m19_c2) 
order m33a_c1 m33a_c2 m33a_c3 m34_c1 m34_c2 m34_c3 m34_c4 m34_c5 m35_c1 m35_c2 m35_c3 m35_c4, after (m33_c)   

destring u1_c, replace

* Passing to missing all "others" values
foreach var in m1_new_c m2_c ma3_c m3_c m4_new_c m5_c ma5_c m6_c m7_c m8_c  ma8_c m9_c  m10_c m11_c  ma11_c m12_c  m13_c m15_c ma15_c m16_c  m18_c m21_c  m22_c m23_c m25_c m26_new_c  m27_c m28_c  m29_c  m30_c  m31_c m32_c  m33_c m33a_c1 m33a_c2 m33a_c3 m36_c  m36a_c  m37_c m37a_c  m38_c m38a_c m39_c  m39a_c m17_c1 m17_c2 m17_c3 m17_c4 m17_c5 m20_c1 m20_c2 m20_c3 m19_c1 m19_c2 m34_c1 m34_c2 m34_c3 m34_c4 m34_c5 m35_c1 m35_c2 m35_c3 m35_c4{
  set more off
  recode `var' (99=.d) (98=.r) (97=.n)
}

foreach var in m2_c m3_c m5_c m6_c m8_c m9_c m11_c m12_c m15_c m16_c m21_c m22_c m25_c m26_new_c m27_c m28_c m29_c m30_c m32_c m36_c m36a_c m37_c m37a_c m38_c m38a_c m39_c {
  replace `var'=. if `var'<1000 & `var'!=0
}


* Dropping variables that have been cleaned
foreach var of local xlist_m {
	capture confirm variable `var'_c
	if !_rc {	
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


*rename variabels to match standardized dataset
rename  m1_new_c 	m1_c
rename  m4_new_c 	m4_c
rename m26_new_c 	m26_c

/*------------------------------------------------------------------------------
                         **  Cleaning Section N	 **
------------------------------------------------------------------------------*/

/*

Raaga's notes: 
	- Missing: n0, 
	- Additional: n19_1 n19_2 n19_3 n19_4 n19_5 n19_6  n22_1 n22_2
	- Update: n17 -> n17a, n17b
 
*/

* Saving variables in section N as a local
local xlist_n "n1 n2 n3 n4 n5 n6 n7 n7a n8 n9 n10 n10a n11 n12 n13 n14 n15 n16 n17a n17b n18 n19 n19_1 n19_2 n19_3 n19_4 n19_5 n19_6 n20 n21 n22 n22_1 n22_2 n22_3 n22_4 n22_5 n22_6 n23 n24 n25 n26 n27 n28 n29 n30 n31 n32 n33 n34 n35 n36 n37 n38 n39 n40 n41 n42 n43 n44 n45 n46 n47 n48"

* Creating a new variables for each variable in local xlist_n
foreach var of local xlist_n {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' // Keeping variable label //
}


* Destring numerical variable
destring n6_c, replace

foreach var in n6_c n19_c n22_c{
  set more off
  split `var', destring
  capture order  `var'1  `var'2  `var'3  `var'4  `var'5  `var'6. after ( `var') 
   drop  `var'
}

* Passing to missing all "others" values
local xlist_nc "n48_c n47_c n46_c n45_c n44_c n43_c n42_c n41_c n40_c n39_c n38_c n37_c n36_c n35_c n34_c n33_c n32_c n31_c n30_c n29_c n28_c n27_c n26_c n25_c n24_c n23_c n22_1_c n22_2_c n22_3_c n22_4_c n22_5_c n22_6_c n21_c n20_c n19_1_c n19_2_c n19_3_c n19_4_c n19_5_c n19_6_c n18_c n17b_c n17a_c n16_c n15_c n14_c n13_c n12_c n11_c n10a_c n10_c n9_c n8_c n7a_c n7_c n6_c1 n6_c2 n6_c3 n6_c4 n6_c5 n6_c6 n5_c n4_c n3_c n2_c n1_c"
foreach var of local xlist_nc {
  set more off
  recode `var' (999 =.d) (99=.d) (98=.r) (97=.n)
}

*FIXMERA there should be a Q asking if the person is married/cohabiting and this should be missing only if unmarried/unpartenered. what is going on otherwise?
recode n7a_c (0=.)						//		Age married = 0		//

/*

. list n5 n6 n7 n7a if n7a == 0

      +------------------------------+
      | n5   n6             n7   n7a |
      |------------------------------|
 233. | No        Yes, widowed     0 |
      +------------------------------+

*/


* Dropping variables that have been cleaned
foreach var of local xlist_n {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


*rename variables to match standaridized dataset
rename n17a_c n17_c

/*------------------------------------------------------------------------------
                         **  Cleaning Section O	 **
------------------------------------------------------------------------------*/

/*

Raaga's notes: 
	- Missing: 
		plot_num o61 o71 o81 o91 o101 o111 o121 o131 o141 o62 o72 o82 o92 o102 o112 o122 o132 o142 o63 o73 o83 o93 o103 o113 o123 o133 o143 o64 o74 o84 o94 o104 o114 o124 o134 o144 o65 o75 o85 o95 o105 o115 o125 o135 o145 o66 o76 o86 o96 o106 o116 o126 o136 o146 o67 o77 o87 o97 o107 o117 o127 o137 o147 o68 o78 o88 o98 o108 o118 o128 o138 o148
	- Additional: o5 o6
 
*/

* Saving variables in section O as a local
local xlist_o "o1 o2 o3 o4 o5 o6"

* Creating a new variables for each variable in local xlist_n
foreach var of local xlist_o {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' // Keeping variable label //
}


* Dropping variables that have been cleaned
foreach var of local xlist_o {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


*rename to match standardized dataset
/*
Raaga's notes: In standardized dataset, section O and P are completely different, hence, renaming Section 'O' in LTFU to 'Q'
*/

local i = 1
while `i' < 7{
    rename o`i'_c q`i'_c 
	local i = `i' + 1
}

********************************************************************************

**Saving Non-Roster Sections 

save "$caregiver_enc/data/LTFU_Cohort_2014_2015_NoRoster.dta", replace

********************************************************************************


/*------------------------------------------------------------------------------
                         **  Cleaning Section D	 **
------------------------------------------------------------------------------*/

/*
Raaga's notes:
	- Missing: fchld_list fchld_list_chk c13_d3_b*_oth d7oth_? d7oth_??  d13a_? d13a_?? e4_? e4_?? e4a_oth_? e4a_oth_?? e5a_oth_? e5a_oth_?? e5c_oth_? e5c_oth_?? e6c_? e6c_??  e7c_? e7c_?? e8_? e8_?? e10 e11 e12 e13 f2_? f2_?? f3_a? f3_a?? f4_? f4_?? f5_? f5_?? f6_? f6_?? f7_? f7_?? fb7_? fb7_?? f8_? f8_?? hht1 f10 f10a f11 f12 f13 kid_? kid_?? chld_? chld_?? chld_total
	- Additional: 
	- update: exa_* -> exA_*, exb_* -> exB_*  - Raaga to check again - not true for all 

*/

preserve
keep id key participation_c hhm_* hhm_r_* d1 d3_b* c13_d3_b* 								 ///
how_dead_d3_b? how_dead_d3_b?? when_dead_d3_b? when_dead_d3_b?? d3_? d3_?? ///
new_mem d3_?_exist d3_??_exist d3_?_all d3_??_all fam_count d1_check 		///
hh_dhedk2 mem_list hhmem_chk fmem_list hhmem_chk1 							///
bam_total mem_id? mem_id?? d4_? d4_?? d5_? d5_??	                        ///
d6_? d6_?? d7_? d7_?? d7oth_? d7oth_?? d8_? d8_?? d9_? d9_?? d9b_? d9b_??	///
d10_? d10_?? d11_?  d11_??													///
d12_? d12_?? d13_? d13_?? d_13_1											///
 hhchd_? hhchd_?? d6d_? d6d_?? 												///
chld_list chld_chk kid1_? kid1_?? chld1_? chld1_?? chld1_total  			///
e2_? e2_?? 																	///
e3_? e3_?? 																	///
e4a_? e4a_?? e4b_? e4b_?? 													///
v1094 v1132 v1170 v1208 v1246 v1284 v1322 v1360 v1398 v1436 				///
v1474 v1512 v1550 v1588 v1626 v1664 v1702 v1740 v1778 v1816 				///
v1854 v1892 v1930 v1968 v2006 v2044 v2082 v2120					///*e5a_x	///
e5a_? e5a_?? e5b_? e5b_?? 													///
v1095 v1133 v1171 v1209 v1247 v1285 v1323 v1361 v1399 v1437 				///
v1475 v1513 v1551 v1589 v1627 v1665 v1703 v1741 v1779 v1817 				///
v1855 v1893 v1931 v1969 v2007 v2045 v2083 v2121					///*e5b_x	///
e6a_? e6a_?? e6b_? e6b_?? 													///
e7a_? e7a_?? e7b_? e7b_??  													///
e8a_? e8a_?? e8b_? e8b_?? 													///
e9a_? e9a_?? e9b_? e9b_?? 													///
e10a_? e10a_?? e10b_? e10b_??												///
e5_? e5_?? e5a_? e5a_?? e5b_? e5b_?? e5c_? e5c_?? 							///
e6a_?_chk e6a_??_chk e6b_?_chk e6b_??_chk e6c_?_chk e6c_??_chk				///
e7a_?_chk e7a_??_chk e7b_?_chk e7b_??_chk e7c_?_chk e7c_??_chk				///
e8_? e8_?? 																	///
v1110 v1148 v1186 v1224 v1262 v1300 v1338 v1376 v1414 v1452					///
v1490 v1528	v1566 v1604 v1642 v1680 v1718 v1756 v1794 v1832 				///
v1870 v1908 v1946 v1984 v2022 v2060 v2098 v2136					///*e9a_x	///
v1111 v1149 v1187 v1225 v1263 v1301 v1339 v1377 v1415 v1453					///
v1491 v1529 v1567 v1605 v1643 v1681 v1719 v1757 v1795 v1833 				///
v1871 v1909 v1947 v1985 v2023 v2061 v2099 v2137					///*e9b_x	///
	e9c_? e9c_?? 								


* Destring numerical variables
foreach var in hhm_r_1 hhm_r_2 hhm_r_3 hhm_r_4 hhm_r_5 hhm_r_6 hhm_r_7 hhm_r_8 hhm_r_9 hhm_r_10 hhm_r_11 hhm_r_12 hhm_r_13 hhm_r_14 hhm_r_15 hhm_r_16 hhm_r_17 hhm_r_18 hhm_r_19 hhm_r_20 hhm_r_21 hhm_r_22 hhm_r_21 hhm_r_22 hhm_r_23 hhm_r_24 e2_1 e2_2 e2_3 e2_4 e2_5 e2_6 e2_7 e2_8 e2_9 e2_10 e2_11 e2_12 e2_13 e2_14 e2_15 e2_16 e2_17 e2_18 e2_19 e2_20 e2_21 e2_22 e2_23 e2_24 e2_25 e2_15 e2_26 e2_27 e2_28 chld1_1 chld1_2 chld1_3 chld1_4 chld1_5 chld1_6 chld1_7 chld1_8 chld1_9 chld1_10 chld1_11 chld1_12 chld1_13 chld1_14 chld1_15 chld1_16 chld1_17 chld1_18 chld1_19 chld1_20 chld1_21 chld1_22 chld1_23 chld1_24 chld1_25 chld1_26 chld1_27 chld1_28{
  set more off
  destring `var', replace
}	
	

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Roster", replace

restore

use "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Roster", clear
								
								
**use "$temp/LTFU_Cohort_2014_2015_NoRoster", clear
/*
local i=1
while `i'<16 {
 set more off
 drop d7_`i'
 rename cc_d7_`i' d7_`i'
local i=`i'+1
}
*/

/*
Missing: d3__exist d3__all fchld_list_chk e10a e10b e10 hht1 f10a
*/
* Destring numerical variables
local xlist_destring "d3__exist d3__all fam_count d1_check hh_dhedk2 hhmem_chk hhmem_chk1 d6d_ chld_chk chld1_ chld1_total  chld_ chld_total e2_ bam_total mem_id d_13_1"
foreach var of local xlist_destring {
  set more off
  capture destring `var', replace
}								
								
*recoding "refused to answer" and "dont know" responses
recode when_dead_d3_b* 	(98 = .r) (99 = .d)
recode how_dead_d3_b*	(98 = .r) (99 = .d)


local i=2
while `i'<29{
 set more off
 replace d7_`i'=10 if (d7oth_`i' == "Himself"| d7oth_`i' == "Self" | d7oth_`i' =="Former  applicant" | d7oth_`i' == "Former applicant" | d7oth_`i' == "Applicant"| d7oth_`i' == "Former applicant")
 replace d7oth_`i' = "" if (d7oth_`i' == "Himself"| d7oth_`i' == "Self" | d7oth_`i' =="Former  applicant" | d7oth_`i' == "Former applicant" | d7oth_`i' == "Applicant"| d7oth_`i' == "Former applicant")
 local i=`i'+1
}


local i=2
while `i'<29{
 set more off
 replace d7_`i'= 3 if (d7oth_`i' == "Grandmother")
 replace d7oth_`i' = "" if (d7oth_`i' == "Grandmother")
 local i=`i'+1
}


local i=2
while `i'<29{
 set more off
 replace d7_`i'= 13 if (d7oth_`i' == "Step father"| d7oth_`i' == "Stepfather" | d7oth_`i' =="Step mother")
 replace d7oth_`i' = "" if (d7oth_`i' == "Step father"| d7oth_`i' == "Stepfather" | d7oth_`i' =="Step mother")
 local i=`i'+1
}

local i=2
while `i'<29{
 set more off
 replace d7_`i'= 15 if (d7oth_`i' == "Nephew"| d7oth_`i' == "Niece")
 replace d7oth_`i' = "" if (d7oth_`i' == "Nephew"| d7oth_`i' == "Niece")
 local i=`i'+1
}

local i=2
while `i'<29{
 set more off
 replace d7_`i'= 18 if (d7oth_`i' == "Wife"| d7oth_`i' == "Husband")
 replace d7oth_`i' = "" if (d7oth_`i' == "Wife"| d7oth_`i' == "Husband")
 local i=`i'+1
}

* Tagging if the applicant is mentioned in the roster (ID 3452 two former applicants in the roster)
local i=1
while `i'<29{
 set more off
 bysort id: gen applicant_`i'= 1 if d7_`i'==10
 local i=`i'+1
}

egen applicant_final = rowtotal(applicant_1 applicant_2 applicant_3 applicant_4 applicant_5 applicant_6 applicant_7 applicant_8 applicant_9 applicant_10 applicant_11 applicant_12 applicant_13 applicant_14 applicant_15 applicant_16 applicant_17 applicant_18 applicant_19 applicant_20 applicant_21 applicant_22 applicant_23 applicant_24 applicant_25 applicant_26 applicant_27 applicant_28)


drop applicant_1 applicant_2 applicant_3 applicant_4 applicant_5 applicant_6 applicant_7 applicant_8 applicant_9 applicant_10 applicant_11 applicant_12 applicant_13 applicant_14 applicant_15 applicant_16 applicant_17 applicant_18 applicant_19 applicant_20 applicant_21 applicant_22 applicant_23 applicant_24 applicant_25 applicant_26 applicant_27 applicant_28 

/* Raaga's addition:
* replacing if current_hh == 0 & applicant_final == 1 and applicant name in the roster
replace current_hh = 1 if current_hh == 0 & applicant_final == 1 & ( id =  146446  | id =  148806  | id =  149417  | id = 151330 | id = 153762 | id =  153838 | id = 153961 | id = 154220 | id = 154422 | id = 156286 | id = 157650 | id = 159914 | id = 1415067 | id = 1418819 | id == 1510772 | id == 1513826)



br a1 a2 current_hh applicant_final hhm_1 hhm_2 hhm_3 hhm_4 hhm_5 hhm_6 hhm_7 hhm_8 hhm_9 hhm_10 hhm_11 hhm_12 hhm_13 hhm_14 hhm_15 hhm_16 hhm_17 hhm_18 hhm_19 hhm_20 hhm_21 hhm_22 hhm_23 hhm_24 if applicant_final == 0 & current_hh == 1
	

create a variable for is applicant moved - only after merge? 

*/

*recoding "refused to answer" i nthe following variables	
recode  d8_* (99=.r)
recode d11_* (99=.r)
recode d12_* (99=.r)
recode d13_* (99=.r) (999=.r)

*cleaning "other" activities 

replace d9_1 = 11 	if  d9b_1 == "Works in coffee cooperative society"
replace d9b_1 = ""	if  d9b_1 == "Works in coffee cooperative society"

*replace d9_2 = 9 	if  d9b_2 == "Cleaner"  // double check
*replace d9b_2 = ""	if  d9b_2 == "Cleaner"	// double check
replace d9_2 = 11 	if  d9b_2 == "Sales personal"
replace d9b_2 = ""	if  d9b_2 == "Sales personal"
replace d9_2 = 11 	if  d9b_2 == "Works at a mobile money outlet"
replace d9b_2 = ""	if  d9b_2 == "Works at a mobile money outlet"

*replace d9_3 = 11 	if  d9b_3 == "Metron"
*replace d9b_3 = ""	if  d9b_3 == "Metron"
*replace d9_3 = 11 	if  d9b_3 == "Police constable"
*replace d9b_3 = ""	if  d9b_3 == "Police constable"
*replace d9_3 = 11 	if  d9b_3 == "Security guard" | d9b_3 == "Security guard for school" 
*replace d9b_3 = ""	if  d9b_3 == "Security guard" | d9b_3 == "Security guard for school" 

replace d9_4 = 17 	if  d9b_4 == "Accountant"
replace d9b_4 = ""	if  d9b_4 == "Accountant"
replace d9_4 = 17 	if  d9b_4 == "Accountant for betting company"
replace d9b_4 = ""	if  d9b_4 == "Accountant for betting company"
*replace d9_4 = 11 	if  d9b_4 == "Game ranger"
*replace d9b_4 = ""	if  d9b_4 == "Game ranger"
replace d9_4 = 1 	if  d9b_4 == "House keeping"
replace d9b_4 = ""	if  d9b_4 == "House keeping"

replace d9_5 = 17 	if  d9b_5 == "Finance section"
replace d9b_5 = ""	if  d9b_5 == "Finance section"
replace d9_5 = 5 	if  d9b_5 == "Pump attendant"
replace d9b_5 = ""	if  d9b_5 == "Pump attendant"

replace d9_6 = 14 	if  d9b_6 == "Primary school teacher"
replace d9b_6 = ""	if  d9b_6 == "Primary school teacher"
*replace d9_6 = 11 	if  d9b_6 == "Professional footballer"
*replace d9b_6 = ""	if  d9b_6 == "Professional footballer"

replace d9_7 = 7 	if  d9b_7 == "Raring cattle" // or 8 
replace d9b_7 = ""	if  d9b_7 == "Raring cattle"

*replace d9_8 = 11 	if  d9b_8 == "Nurse"
*replace d9b_8 = ""	if  d9b_8 == "Nurse"
*replace d9_8 = 11 	if  d9b_8 == "Soldier"
*replace d9b_8 = ""	if  d9b_8 == "Soldier"
replace d9_8 = 14 	if  d9b_8 == "Teacher"
replace d9b_8 = ""	if  d9b_8 == "Teacher"

*replace d9_10 = 11 	if  d9b_10 == "Updf soldier"
*replace d9b_10 = ""	if  d9b_10 == "Updf soldier"	

replace d9_11 = 11 	if  d9b_11 == "Employed in someone's shop"
replace d9b_11 = ""	if  d9b_11 == "Employed in someone's shop"

replace d9_26 = 17 	if  d9b_26 == "Sales and marketing of company"
replace d9b_26 = ""	if  d9b_26 == "Sales and marketing of company"

replace d9_27 = 14 	if  d9b_27 == "Head Teacher"
replace d9b_27 = ""	if  d9b_27 == "Head Teacher"


/*------------------------------------------------------------------------------
                         **  Cleaning Section E	 **
------------------------------------------------------------------------------*/


*renaming variables to match standardized dataset
rename e4a_* e4a_y22_*
rename e4b_* e4b_y22_*

rename e5a_* e5a_y21_*
rename e5b_* e5b_y21_*

rename e6a_? e6a_y20_?			// to avoid rename e6a_x_check
rename e6a_?? e6a_y20_??
rename e6b_? e6b_y20_?
rename e6b_?? e6b_y20_??

rename e7a_? e7a_y19_?			// to avoid rename e7a_x_check
rename e7a_?? e7a_y19_??
rename e7b_? e7b_y19_?
rename e7b_?? e7b_y19_??

rename e8a_* e8a_y18_*
rename e8b_* e8b_y18_*

rename e9a_* e9a_y17_*
rename e9b_* e9b_y17_*

rename e10a_* e10a_y16_*
rename e10b_* e10b_y16_*

*label variables
local i = 1
while `i' <29 {
    label var e4a_y22_`i' "Did ${fam_`i''s} attend school in the 2022 school year?"
	label var e4b_y22_`i' "Which grade did ${fam_`i''s} attend in 2022?"
	label var e5a_y21_`i' "Did ${fam_`i''s} attend school in the 2021 school year?"
	label var e5b_y21_`i' "Which grade did ${fam_`i''s} attend in 2021?"
	label var e6a_y20_`i' "Did ${fam_`i''s} attend school in the 2020 school year?"
	label var e6b_y20_`i' "Which grade did ${fam_`i''s} attend in 2020?"
	label var e7a_y19_`i' "Did ${fam_`i''s} attend school in the 2019 school year?"
	label var e7b_y19_`i' "Which grade did ${fam_`i''s} attend in 2019?"
	label var e8a_y18_`i' "Did ${fam_`i''s} attend school in the 2018 school year?"
	label var e8b_y18_`i' "Which grade did ${fam_`i''s} attend in 2018?"
	label var e9a_y17_`i' "Did ${fam_`i''s} attend school in the 2017 school year?"
	label var e9b_y17_`i' "Which grade did ${fam_`i''s} attend in 2017?"
	label var e10a_y16_`i' "Did ${fam_`i''s} attend school in the 2016 school year?"
	label var e10b_y16_`i' "Which grade did ${fam_`i''s} attend in 2016?"
	local i = `i' + 1
}

rename v1094 e5a_1
rename v1095 e5b_1	

rename v1132 e5a_2
rename v1133 e5b_2

rename v1170 e5a_3
rename v1171 e5b_3

rename v1208 e5a_4
rename v1209 e5b_4

rename v1246 e5a_5
rename v1247 e5b_5

rename v1284 e5a_6
rename v1285 e5b_6

rename v1322 e5a_7
rename v1323 e5b_7

rename v1360 e5a_8
rename v1361 e5b_8

rename v1398 e5a_9
rename v1399 e5b_9

rename v1436 e5a_10
rename v1437 e5b_10

rename v1474 e5a_11
rename v1475 e5b_11

rename v1512 e5a_12
rename v1513 e5b_12

rename v1550 e5a_13
rename v1551 e5b_13

rename v1588 e5a_14
rename v1589 e5b_14

rename v1626 e5a_15
rename v1627 e5b_15

rename v1664 e5a_16
rename v1665 e5b_16

rename v1702 e5a_17
rename v1703 e5b_17

rename v1740 e5a_18
rename v1741 e5b_18

rename v1778 e5a_19
rename v1779 e5b_19

rename v1816 e5a_20
rename v1817 e5b_20

rename v1854 e5a_21
rename v1855 e5b_21

rename v1892 e5a_22
rename v1893 e5b_22

rename v1930 e5a_23
rename v1931 e5b_23

rename v1968 e5a_24
rename v1969 e5b_24

rename v2006 e5a_25
rename v2007 e5b_25

rename v2044 e5a_26
rename v2045 e5b_26

rename v2082 e5a_27
rename v2083 e5b_27

rename v2120 e5a_28
rename v2121 e5b_28

rename v1110 e9a_1
rename v1111 e9b_1

rename v1148 e9a_2
rename v1149 e9b_2

rename v1186 e9a_3
rename v1187 e9b_3

rename v1224 e9a_4
rename v1225 e9b_4

rename v1262 e9a_5
rename v1263 e9b_5

rename v1300 e9a_6
rename v1301 e9b_6

rename v1338 e9a_7
rename v1339 e9b_7

rename v1376 e9a_8
rename v1377 e9b_8

rename v1414 e9a_9
rename v1415 e9b_9

rename v1452 e9a_10
rename v1453 e9b_10

rename v1490 e9a_11
rename v1491 e9b_11

rename v1528 e9a_12
rename v1529 e9b_12

rename v1566 e9a_13
rename v1567 e9b_13

rename v1604 e9a_14
rename v1605 e9b_14

rename v1642 e9a_15
rename v1643 e9b_15 				

rename v1680 e9a_16
rename v1681 e9b_16

rename v1718 e9a_17
rename v1719 e9b_17

rename v1756 e9a_18
rename v1757 e9b_18

rename v1794 e9a_19
rename v1795 e9b_19

rename v1832 e9a_20
rename v1833 e9b_20

rename v1870 e9a_21
rename v1871 e9b_21

rename v1908 e9a_22
rename v1909 e9b_22

rename v1946 e9a_23
rename v1947 e9b_23

rename v1984 e9a_24
rename v1985 e9b_24

rename v2022 e9a_25
rename v2023 e9b_25 				

rename v2060 e9a_26
rename v2061 e9b_26

rename v2098 e9a_27
rename v2099 e9b_27

rename v2136 e9a_28
rename v2137 e9b_28 

*label variables
local i = 1
while `i' <29 {
    label var e5a_`i' "Was ${fam_`i''s} a day scholar or a boarder at the school?"
	label var e5b_`i' "What is the distance to the school in km?"
	label var e5c_`i' "How does ${fam_`i''s} usually get to school?"
	
	rename e6a_`i'_chk e6a_chk_`i'
	label var e6a_chk_`i' "Term 1 basic fees"
	rename e6b_`i'_chk e6b_chk_`i'
	label var e6b_chk_`i' "Term 2 basic fees"
	rename e6c_`i'_chk e6c_chk_`i' 
	label var e6c_chk_`i' "Term 3 basic fees"
	
	rename e7a_`i'_chk e7a_chk_`i'
	label var e7a_chk_`i' "Term 1 extra fees"
	rename e7b_`i'_chk e7b_chk_`i'
	label var e7b_chk_`i' "Term 2 extra fees"
	rename e7c_`i'_chk e7c_chk_`i' 
	label var e7c_chk_`i' "Term 3 extra fees"
	
	label var e8_`i' "What was ${fam_`i''s} most recent aggregate score?"
	
	label var e9a_`i' "What was ${fam_`i''s} most recent position in class?"
	label var e9b_`i' "Out of how many?"
	label var e9c_`i' "What was ${fam_`i''s} most recent average?"
	
	local i = `i' + 1
}

*replace missing vaulues with "."
recode e4b_y22_* 	(98=.r) (99=.d)
recode e5b_y21_* 	(98=.r) (99=.d)
recode e6b_y20_* 	(98=.r) (99=.d)
recode e7b_y19_* 	(98=.r) (99=.d)
recode e8b_y18_* 	(98=.r) (99=.d)
recode e9b_y17_* 	(98=.r) (99=.d)
recode e10b_y16_*	(98=.r) (99=.d)

recode e9b_? 	(98=.r) (99=.d)		
recode e9b_?? 	(98=.r) (99=.d)

recode e5_* 	(99=.d)
recode e5b_* 	(98=.r) (99=.d)


recode e6a_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)
recode e6b_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)
recode e6c_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)

recode e7a_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)
recode e7b_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)
recode e7c_chk_* (88=.m) (98=.m) (99=.m) (999 =.m) (-999 =.m)

recode e8_*		(-999 = .m) (-888 = .m) (999 = .m)	(97 = .d) (98 = .r) (99 = .d)			// general cases

recode e8_4		(369 = .m) 
recode e8_5		(354 = .m) (358 = .m) 
recode e8_7		(1247 = .m)
recode e8_9		(999923 = .m)  
recode e8_22	(246 = .m) (523 = .m) (50000 = .m) 

recode e9a_*	(-999 = .m) (-888 = .m) (999 = .m)	(97 = .d) (98 = .r) (99 = .d) (0 = .) // position in class cannot be 0

*tab e9b_1_2 - dropping usual outliers is dropping 106 obersevation out of 281 totday

recode e9c_*	(-999 = .m) (-888 = .m) (999 = .m)	(97 = .d) (98 = .r) (99 = .d)

recode e9c_1 (260 = .m)
recode e9c_2 (150 = .m) (200 = .m) (208 = .m) (375 = .m) (9999 = .m)
recode e9c_3 (280 = .m) (350 = .m) (9999 = .m)	 // recode =100 as well?
recode e9c_4 (137 = .m) (225 = .m) (290 = .m) (376 = .m) 
recode e9c_5 (292 = .m) (330 = .m) (458 = .m) (9999 = .m) 
recode e9c_6 (270 = .m) 
recode e9c_7 (1247 = .m) (9999 = .m)
recode e9c_8 (250 = .m) 
recode e9c_10 (220 = .m)
recode e9c_11 (165 = .m) (427 = .m)
recode e9c_12 (202 = .m) 
recode e9c_22 (275 = .m) (320 = .m) (523 = .m) (50000 = .m) (9999 = .m)
recode e9c_23 (200 = .m) (310 = .m)
recode e9c_24 (280 = .m) (320 = .m)
recode e9c_25 (340 = .m) (358 = .m)
recode e9c_26 (385 = .m)


foreach x of varlist _all{
  set more off
  rename (`x') cl_`x' 
}

rename cl_id id
rename cl_mem_id* mem_id*


* Dropping duplicated variables
drop cl_hhm_r_*_c cl_hhm_*_c 

*rename for reshaping
rename cl_d3_*_exist cl_d3_exist_*
rename cl_d3_*_all cl_d3_all_*	

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_wide.dta", replace


reshape long mem_id cl_hhm_ cl_hhm_r_ cl_d6d_ cl_d3_b cl_c13_d3_b			///
cl_when_dead_d3_b cl_how_dead_d3_b cl_d3_ cl_d3_exist_ cl_d3_all_ 			///
cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ 		///	
cl_d11_ cl_d12_ cl_d13_ cl_hhchd_ cl_kid1_ cl_chld1_ 	///
cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ 				///
cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ 	///
cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ 							///		
cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ 			///
cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_, i(id) j(hh_mem_id)


/*------------------------------------------------------------------------------
                         **  Cleaning HH Roster**
------------------------------------------------------------------------------*/

**Cleaning member id to match standardized dataset (using pull dataset)
rename id id_new  
rename cl_hhm_ name_hhmember
rename cl_d7_ relationship_hhmember



/*
preserve 

keep id_new name_hhmember relationship_hhmember

drop if name_hhmember == ""

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------+
  | Group    Obs   id_new   name_hhmem~r   relati~r |
  |-------------------------------------------------|
  |     1   1218   154160          Komol     Cousin |		// hh_mem_id: 25, 26 (everything but age same - 0,1) - ADD SEPERATELY
  |     1   1219   154160          Komol     Cousin |
  |     2   2093   158987   Kasule Hakim     Father |		// hh_mem_id: 2, 22 (everything but cl_hhm, cl_hhm_r, cl_d3_b same)
  |     2   2096   158987   Kasule Hakim     Father |		// looks like the same person recorded twice - DROP
  +-------------------------------------------------+

*/
restore
*/

** Fixing duplicate names and id problem by adding them as a seperate file
preserve 

keep if (id_new == 154160 & hh_mem_id == 26)  
drop hh_mem_id

tempfile temp1
save `temp1'

restore


** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 154160 & hh_mem_id == 26) | (id_new == 158987 & hh_mem_id == 22)


drop if name_hhmember == ""

drop hh_mem_id			// will merge to get the right memid 

tempfile temp2
save `temp2'


use "$caregiver_enc/data/Cohort2014_2015_LTFU_caregiver_pulldata.dta", clear

reshape long id_hhmember name_hhmember sex_hhmember age_hhmember relationship_hhmember exists_hhmember, i(id_new) j(hh_mem_id)

keep id_new hh_mem_id name_hhmember relationship_hhmember

drop if name_hhmember == ""


/*
drop hh_mem_id

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------------+
  | Group    Obs    id_new       name_hhmember   relati~r |
  |-------------------------------------------------------|
  |     1    698    145743       JOUSI KIKOBYE          5 |
  |     1    699    145743       JOUSI KIKOBYE          5 |		// everything but age (10, 20) same - ADD SEPERATELY
  |     2    706    145743    NAKATALE TAPENIS          5 |
  |     2    707    145743    NAKATALE TAPENIS          5 |		// everything but age (17, 15) same - ADD SEPERATELY
  |     3   3666    158969      Mukose Abraham          5 |
  |-------------------------------------------------------|
  |     3   3667    158969      Mukose Abraham          5 |		// everything but age (22, 15) same - ADD SEPERATELY
  |     4   8438   1516594   Kugonza Josephine          5 |
  |     4   8439   1516594   Kugonza Josephine          5 |		// everything same (except member id - hence two rows) - DROP! 
  +-------------------------------------------------------+
*/

*/

/*
** Fixing duplicate names and id problem by adding them as a seperate file
preserve

keep if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5)

tempfile temp3
save `temp3'

restore

*/

** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5) | (id_new == 1516594 & name_hhmember == "Kugonza Josephine" & hh_mem_id == 5)

merge 1:1 id_new name_hhmember relationship_hhmember using `temp2'

/*

    Result                      Number of obs
    -----------------------------------------
    Not matched                        13,966
        from master                     6,983  (_merge==1)
        from using                      6,983  (_merge==2)

    Matched                             2,051  (_merge==3)
    -----------------------------------------

*/

rename _merge merge

append using `temp1'
*append using `temp3'			// Note: additional rows are from pull data file hence will not have additional information collected in LTFU


sort id_new hh_mem_id, stable // added stable as it would not be otherwise reproducible

by id_new:gen mem_id_new = _n
order mem_id_new , after (hh_mem_id)
drop hh_mem_id /* cl_d1 */ cl_new_mem cl_d3_exist_ cl_d3_all_ cl_d1_check 		///
	cl_hh_dhedk2 cl_mem_list cl_fmem_list cl_bam_total  // only in master data, ie pull data

rename name_hhmember* cl_hhm_*
rename relationship_hhmember* cl_d7_*

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_long.dta", replace

drop if merge == 1		// dropped if name only existing in pull data and not ltfu data

reshape wide cl_d3_ cl_d7_ mem_id cl_d4_ cl_d5_ cl_d6_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_d6d_ cl_hhm_ cl_hhm_r_ cl_d3_b cl_c13_d3_b cl_when_dead_d3_b cl_how_dead_d3_b cl_hhchd_ cl_kid1_ cl_chld1_ cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_ merge, i(id_new) j(mem_id_new) 

rename id_new id

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_merge-wide.dta", replace


preserve 

reshape long mem_id cl_hhm_ cl_hhm_r_ cl_d6d_ cl_d3_b cl_c13_d3_b			///
cl_when_dead_d3_b cl_how_dead_d3_b cl_d3_ cl_d3_exist_ cl_d3_all_ 			///
cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ 		///	
cl_d11_ cl_d12_ cl_d13_ cl_hhchd_ cl_kid1_ cl_chld1_ 	///
cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ 				///
cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ 	///
cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ 							///		
cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ 			///
cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_, i(id) j(hh_mem_id)

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_merge-long.dta", replace

restore


/*------------------------------------------------------------------------------
                         **  Creating Education Roster	 **
------------------------------------------------------------------------------*/

preserve

keep id cl_hhm_? cl_hhm_?? mem_id? mem_id?? cl_hhm_? cl_hhm_??				///
cl_hhm_r_? cl_hhm_r_?? cl_d6d_? cl_d6d_?? cl_hhchd_? cl_hhchd_?? 			/// 
cl_kid1_? cl_kid1_?? cl_chld_chk cl_chld_chk cl_chld1_? cl_chld1_?? 		///
cl_e2_? cl_e2_?? cl_e3_? cl_e3_??											///
cl_e4a_y22_? cl_e4a_y22_?? cl_e4b_y22_? cl_e4b_y22_??						///
cl_e5a_y21_? cl_e5a_y21_?? cl_e5b_y21_? cl_e5b_y21_?? 						///
cl_e6a_y20_? cl_e6a_y20_?? cl_e6b_y20_? cl_e6b_y20_?? 						///	
cl_e7a_y19_? cl_e7a_y19_?? cl_e7b_y19_? cl_e7b_y19_?? 						///
cl_e8a_y18_? cl_e8a_y18_?? cl_e8b_y18_? cl_e8b_y18_?? 						///
cl_e9a_y17_? cl_e9a_y17_?? cl_e9b_y17_? cl_e9b_y17_?? 						///
cl_e10a_y16_? cl_e10a_y16_?? cl_e10a_y16_? cl_e10a_y16_?? 					///
cl_e5_? cl_e5_?? cl_e5a_? cl_e5a_?? cl_e5b_? cl_e5b_?? cl_e5c_? cl_e5c_?? 	///
cl_e6a_chk_? cl_e6a_chk_?? cl_e6b_chk_? 									///
cl_e6b_chk_?? cl_e6c_chk_? cl_e6c_chk_??									///
cl_e7a_chk_? cl_e7a_chk_?? cl_e7b_chk_? 									///
cl_e7b_chk_?? cl_e7c_chk_? cl_e7c_chk_??									///
cl_e8_? cl_e8_?? cl_e9a_? cl_e9a_?? cl_e9b_? cl_e9b_?? cl_e9c_? cl_e9c_??	///
cl_d7_? cl_d7_?? cl_d6_? cl_d6_?? cl_d8_? ??

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_EducRoster_wide.dta", replace

reshape long mem_id cl_d7_ cl_hhm_ cl_hhm_r_ cl_d6d_ cl_hhchd_ cl_kid1_ cl_chld1_ 	///
cl_d6_ cl_d8_ cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ 				///
cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ 	///
cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ 							///		
cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ 			///
cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_, i(id) j(chld_id) 

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_EducRoster_long.dta", replace

*merge m:1 using "" 

restore



/*------------------------------------------------------------------------------
                         **  Creating Household Roster	 **
------------------------------------------------------------------------------*/

preserve 

/*
keep id cl_hhm_? cl_hhm_?? mem_id? mem_id?? 				///
cl_hhm_r_? cl_hhm_r_?? cl_d6d_? cl_d6d_?? cl_d? cl_d?? cl_new_mem ///
cl_hh_dhedk2 cl_d1_check cl_fmem_list cl_mem_list cl_bam_total ///
cl_d3_b1? cl_d3_b?? cl_c13_d3_b? cl_c13_d3_b?? 						///
cl_when_dead_d3_b? cl_when_dead_d3_b?? cl_how_dead_d3_b? cl_how_dead_d3_b?? ///
cl_d3_? cl_d3_?? cl_d3_exist_? cl_d3_exist_?? cl_d3_all_? cl_d3_all_?? 		///
mem_id? mem_id?? cl_d4_? cl_d4_?? cl_d5_? cl_d5_?? cl_d6_? cl_d6_?? 		///
cl_d7_? cl_d7_?? cl_d7oth_? cl_d7oth_?? cl_d8_? cl_d8_?? 					///
cl_d9_? cl_d9_?? cl_d9b_? cl_d9b_?? 										///
cl_d10_? cl_d10_?? cl_d11_? cl_d11_?? 										///	
cl_d12_? cl_d12_?? cl_d13_? cl_d13_??
*/
drop  cl_hhchd_? cl_hhchd_?? 			/// 
cl_kid1_? cl_kid1_?? cl_chld_chk cl_chld_chk cl_chld1_? cl_chld1_?? 		///
cl_e2_? cl_e2_?? cl_e3_? cl_e3_??											///
cl_e4a_y22_? cl_e4a_y22_?? cl_e4b_y22_? cl_e4b_y22_??						///
cl_e5a_y21_? cl_e5a_y21_?? cl_e5b_y21_? cl_e5b_y21_?? 						///
cl_e6a_y20_? cl_e6a_y20_?? cl_e6b_y20_? cl_e6b_y20_?? 						///	
cl_e7a_y19_? cl_e7a_y19_?? cl_e7b_y19_? cl_e7b_y19_?? 						///
cl_e8a_y18_? cl_e8a_y18_?? cl_e8b_y18_? cl_e8b_y18_?? 						///
cl_e9a_y17_? cl_e9a_y17_?? cl_e9b_y17_? cl_e9b_y17_?? 						///
cl_e10a_y16_? cl_e10a_y16_?? cl_e10a_y16_? cl_e10a_y16_?? 					///
cl_e5_? cl_e5_?? cl_e5a_? cl_e5a_?? cl_e5b_? cl_e5b_?? cl_e5c_? cl_e5c_?? 	///
cl_e6a_chk_? cl_e6a_chk_?? cl_e6b_chk_? 									///
cl_e6b_chk_?? cl_e6c_chk_? cl_e6c_chk_??									///
cl_e7a_chk_? cl_e7a_chk_?? cl_e7b_chk_? 									///
cl_e7b_chk_?? cl_e7c_chk_? cl_e7c_chk_??									///
cl_e8_? cl_e8_?? cl_e9a_? cl_e9a_?? cl_e9b_? cl_e9b_?? cl_e9c_? cl_e9c_??

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_HHRoster_wide.dta", replace

reshape long mem_id cl_hhm_ cl_hhm_r_ cl_d6d_ cl_d3_b cl_c13_d3_b			///
cl_when_dead_d3_b cl_how_dead_d3_b cl_d3_ cl_d3_exist_ cl_d3_all_ 			///
cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ 		///	
cl_d11_ cl_d12_ cl_d13_, i(id) j(hh_mem_id)

save "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_HHRoster_long.dta", replace


restore


/*------------------------------------------------------------------------------
                         **  Merging Roster and Non-Roster	 **
------------------------------------------------------------------------------*/

* Merging the Roster and Non roster dataset together
clear all	
set more off

use "$caregiver_enc/data/LTFU_Cohort_2014_2015_NoRoster.dta", clear		

* Drop cleaned variables

drop hhm_* hhm_r_* d1 d3_b* c13_d3_b* 								 ///
how_dead_d3_b? how_dead_d3_b?? when_dead_d3_b? when_dead_d3_b?? d3_? d3_?? ///
new_mem d3_?_exist d3_??_exist d3_?_all d3_??_all fam_count d1_check 		///
hh_dhedk2 mem_list hhmem_chk fmem_list hhmem_chk1 							///
bam_total mem_id? mem_id?? d4_? d4_?? d5_? d5_??	                        ///
d6_? d6_?? d7_? d7_?? d7oth_? d7oth_?? d8_? d8_?? d9_? d9_?? d9b_? d9b_??	///
d10_? d10_?? d11_?  d11_??													///
d12_? d12_?? d13_? d13_?? d_13_1											///
 hhchd_? hhchd_?? d6d_? d6d_?? 												///
chld_list chld_chk kid1_? kid1_?? chld1_? chld1_?? chld1_total  			///
e2_? e2_?? 																	///
e3_? e3_?? 																	///
e4a_? e4a_?? e4b_? e4b_?? 													///
v1094 v1132 v1170 v1208 v1246 v1284 v1322 v1360 v1398 v1436 				///
v1474 v1512 v1550 v1588 v1626 v1664 v1702 v1740 v1778 v1816 				///
v1854 v1892 v1930 v1968 v2006 v2044 v2082 v2120					///*e5a_x	///
e5a_? e5a_?? e5b_? e5b_?? 													///
v1095 v1133 v1171 v1209 v1247 v1285 v1323 v1361 v1399 v1437 				///
v1475 v1513 v1551 v1589 v1627 v1665 v1703 v1741 v1779 v1817 				///
v1855 v1893 v1931 v1969 v2007 v2045 v2083 v2121					///*e5b_x	///
e6a_? e6a_?? e6b_? e6b_?? 													///
e7a_? e7a_?? e7b_? e7b_??  													///
e8a_? e8a_?? e8b_? e8b_?? 													///
e9a_? e9a_?? e9b_? e9b_?? 													///
e10a_? e10a_?? e10b_? e10b_??												///
e5_? e5_?? e5a_? e5a_?? e5b_? e5b_?? e5c_? e5c_?? 							///
e6a_?_chk e6a_??_chk e6b_?_chk e6b_??_chk e6c_?_chk e6c_??_chk				///
e7a_?_chk e7a_??_chk e7b_?_chk e7b_??_chk e7c_?_chk e7c_??_chk				///
e8_? e8_?? 																	///
v1110 v1148 v1186 v1224 v1262 v1300 v1338 v1376 v1414 v1452					///
v1490 v1528	v1566 v1604 v1642 v1680 v1718 v1756 v1794 v1832 				///
v1870 v1908 v1946 v1984 v2022 v2060 v2098 v2136					///*e9a_x	///
v1111 v1149 v1187 v1225 v1263 v1301 v1339 v1377 v1415 v1453					///
v1491 v1529 v1567 v1605 v1643 v1681 v1719 v1757 v1795 v1833 				///
v1871 v1909 v1947 v1985 v2023 v2061 v2099 v2137					///*e9b_x	///
e9c_? e9c_?? 								
 

merge 1:1 id using "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_merge-wide.dta", nogen
 
/*

 Result                      Number of obs
    -----------------------------------------
    Not matched                             0
    Matched                             1,130  
    -----------------------------------------


*/

gen id_new = id


* Destring variables
* Index_c
*split index_c, p(/)
* gen index=index_c1+index_c2 //no observations
destring index_c, replace   //(1325 missing values generated)
*order index, after (index_c)
* drop index_c
*drop index_c1 index_c2
* rename index index_c

quietly compress

save "$caregiver_enc/data/LTFU_Cohort_2014_2015_cleaned.dta", replace

preserve

***** Deidentify 

	drop deviceid data_phone simid duration audit_* statement_of_consent_* start_* formdef_version submissiondate starttime endtime start today q6_c
	
	drop a1_c a2_c a4_c a5_c  a7_c a8_c app_sur_c app_oth_c resp_surname_c resp_othername_c enu_name enu_code enu_name_check enu_name_checkfail tutor_sur_c village current_hh_vil_c interview_gpslatitude interview_gpslongitude interview_gpsaltitude interview_gpsaccuracy interview_location_other interview_location_detail interview_location_detail_replac aa6_yes_nametrue aa6_yes_othernametrue a16_c a16a_c a16b_c a16d_c resp_phone1_c resp_phone2_c tutor_phone_c tutor_phone2_c aa6_yes_numbertrue1 aa6_yes_numbertrue2 aa6_yes_viltrue aa6_yes_directionstrue current_hh_sub_c current_hh_boarding_c aa6_yes_knownumbertrue aa6_yes_regtrue aa6_yes_distrue aa6_yes_knowdirectionstrue aa6_yes_knowloctrue  aa6_no_other
	
	drop cl_hhchd_* cl_hhm_* cl_d3_* cl_kid1_*
	
save "$caregiver_mast/Data/LTFU_Cohort_2014_2015_cleaned_deid.dta", replace

restore

gen ltfu = 1

append using "$caregiver_enc/data/Cohort_2014_2015_StandardizedDataset.dta"

**extending baseline dummy to include ltfu rows
replace baseline = 0 if baseline == . & ltfu == 1 

**extending ltfu dummy to include baseline and FU rows
replace ltfu = 0 if ltfu != 1 & ltfu == .	

**Adding a dummy variable for care giver data - to differentiate between caregiver and 	

save "$caregiver_enc/data/LTFU_Cohort_2014_2015_StandardizedDataset.dta", replace

***** Deidentify

	drop deviceid data_phone simid duration audit_* statement_of_consent_* start_* formdef_version submissiondate starttime endtime start today q6_c
	
	drop a1_c a2_c a4_c a5_c  a7_c a8_c app_sur_c app_oth_c resp_surname_c resp_othername_c enu_name enu_code enu_name_check enu_name_checkfail tutor_oth_c tutor_sur_c village current_hh_vil_c interview_gpslatitude interview_gpslongitude interview_gpsaltitude interview_gpsaccuracy interview_location_other interview_location_detail interview_location_detail_replac aa6_yes_nametrue aa6_yes_othernametrue  a16_c a16a_c a16b_c a16d_c resp_phone1_c resp_phone2_c tutor_phone_c tutor_phone2_c aa6_yes_numbertrue1 aa6_yes_numbertrue2 aa6_yes_viltrue aa6_yes_directionstrue current_hh_sub_c current_hh_boarding_c aa6_yes_checktrue aa6_yes_knownumbertrue aa6_yes_regtrue aa6_yes_distrue aa6_yes_knowdirectionstrue aa6_yes_knowloctrue  aa6_no_other
	
	drop cl_hhchd_* cl_hhm_* cl_d3_* cl_kid1_* 
	
	drop app_mother app_father cl_e*_name resp_surname_2015_c resp_othername_2015_c cl_chld_list aa1 aa4 bb_4_2014_c cl_fchld_list cl_mem_list cl_fmem_list o6*_c a11_c a12_c a13_c a14_c aa9 app_phone1 app_phone1_owner app_phone2 app_phone2_owner a14a_c loc_verify loc_verificationa10_1 loc_verificationa10 loc_verificationa11  loc_verificationa13 loc_verificationa14 bb_4_201*_other_c a17_baseline_c a17_2_c gps* app_phone1_rel app_phone2_rel app_bd_c app_sur_2015_c app_oth_2015_c app_bd_2015_c cl_kid_* current_phone_c
	


save "$caregiver_mast/Data/LTFU_Cohort_2014_2015_StandardizedDataset_deid.dta", replace



