
*---------------------------------------------------------------------------*
*Description: 	Generate outcomes for analysis 								*		
*																			* 
*Date:			10/10/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Temp/Cohort2014_2015_AttritionAnalysis_Data.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU_Cohort_2014_2015_ApplicantDataset_cleaned_deid.dta", replace

/*  merge moved to cleaning .do file
rename id id_new 

merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta", nogen 	// keep all observation for bounds

replace  baseline = 1 if notfoundatFU !=. & NSC_intdcode != . */ 	

**Dummy for those in control group
gen C_0 = (T_0 == 0)

label define treat 0 Control 1 Treatment
label value T_0 treat

**Dummy for applicants who participated in the survey 
gen participation_alum = (participation == 1)


/*******************************************************************************
							Outcome 0: Demographics
*******************************************************************************/
gen out0_alone = (b10_c == 1) if participation_alum == 1
lab var out0_alone "Living Alone"

gen out0_caregiver = (pov0_c == 1) if participation_alum == 1
lab var out0_caregiver "Living with Caregiver" 

gen out0_partner = (i1_c == 1 | i1_c == 3) if participation_alum == 1
lab var out0_partner "Living with spouse/partner" 

gen out0_hhsize = b10_c if participation_alum == 1
lab var out0_hhsize "Household size" 

gen out0_minor = b11_c if participation_alum == 1
lab var out0_minor "Number of minors in household" 

gen out0_urban_b = (NSC_intdcode == 30 | NSC_intdcode == 44 | NSC_intdcode == 78 | NSC_intdcode == 79 ) if participation_alum == 1
lab var out0_urban_b "Urban at Baseline"	

gen out0_urban = (district == 30 | district == 44 | district == 78 | district == 79 )  if participation_alum == 1
lab var out0_urban "Urban at LTFU"		// urban is district in Gulu, Kampala, Mbale, Mbarara

gen out0_moved_urban = (out0_urban_b == 0 & out0_urban == 1) if participation_alum == 1
lab var out0_moved_urban "Moved to Urban"

gen out0_moved_rural = (out0_urban_b == 1 & out0_urban == 0) if participation_alum == 1
lab var out0_moved_rural "Moved to Rural"

gen out0_enrolledschool = c7_c if participation_alum == 1
lab var out0_enrolledschool "Enrolled in School"

gen out0_working = (e2_o_1_c == 1 | e2_o_2_c == 1 | e2_o_3_c == 1 | e2_o_4_c == 1) if participation_alum == 1
lab var out0_working "Working" 

gen time_use_school = (out0_enrolledschool == 1 & out0_working == 0) if participation_alum == 1
lab var time_use_school "Studying"
gen time_use_work = (out0_enrolledschool == 0 & out0_working == 1) if participation_alum == 1
lab var time_use_work "Working"
gen time_use_both = (out0_enrolledschool == 1 & out0_working == 1) if participation_alum == 1
lab var time_use_both "Both"
gen time_use_neither = (out0_enrolledschool == 0 & out0_working == 0) if participation_alum == 1
lab var time_use_neither "Neither"

local demographic_vars out0_alone out0_caregiver out0_partner out0_hhsize out0_minor out0_working out0_enrolledschool 
 
/*******************************************************************************
							Outcome 1: Education Scholarships
*******************************************************************************/

gen out1_receivescholarship = (c5_0a_c == 1) if participation_alum == 1
lab var out1_receivescholarship "Received Scholarship" 

gen out1_acceptscholarship = (c5_0b_c == 1 & out1_receivescholarship == 1) if participation_alum == 1
lab var out1_acceptscholarship "Accepted Scholarship"

gen out1_scholarshipmonths = abs(round((c5_2_c - c5_1_c)/(365/12))) if out1_receivescholarship == 1 & out1_acceptscholarship == 1 & participation_alum == 1
lab var out1_scholarshipmonths "Months of Scholarship"

/*
. list out1_scholarshipmonths c5_2_c  c5_1_c if out1_scholarshipmonths <=0  //FIXMEBL: FYI: fixed this by using "abs()" in code above

      +----------------------------------+
      | out1_s~s      c5_2_c      c5_1_c |
      |----------------------------------|
 352. |      -75   01feb2015   01may2021 |
 438. |        0   01feb2014   01feb2014 |
 472. |       -1   01feb2014   01mar2014 |
1056. |        0   01feb2015   01feb2015 |
      +----------------------------------+

*/

replace out1_scholarshipmonths = 1 if out1_scholarshipmonths == 0  // 2 changes made // FIXMEBL: assuming applicants received atleast 1 month of scholarships

egen out1_scholarshipitems = rowtotal(c5_3_2_c c5_3_3_c c5_3_4_c c5_3_5_c c5_3_6_c c5_3_7_c c5_3_8_c c5_3_9_c c5_3_10_c c5_3_other_c) if out1_receivescholarship == 1 & out1_acceptscholarship == 1 & participation_alum == 1
lab var out1_scholarshipitems "Scholarship Items"


/*
preserve 

keep id_new T_0 a1_c a2_c out1_receivedscholarship out1_acceptedscholarship c5_2_c  c5_1_c 
keep if T_0 == 0 & out1_receivedscholarship == 1

export excel "$output/LTFU_2022_Cohort_2014_2015_Scholars_In_Control.xls", firstrow(varlabel) replace
restore
*/

local scholarship_vars out1_receivescholarship out1_acceptscholarship out1_scholarshipmonths out1_scholarshipitems
swindex `scholarship_vars', normby(C_0) gen(index_scholarship)	
lab var index_scholarship "Scholarship Index"

/*******************************************************************************
			Outcome 4: Savings and Business Assets
*******************************************************************************/

gen out4_assets_land = e34_c if participation_alum == 1
replace out4_assets_land = 0 if (out4_assets_land == . | out4_assets_land == .m)  & participation_alum == 1
lab var out4_assets_land "Value of Land"

gen out4_assets_house = e35_c if participation_alum == 1
replace out4_assets_house = 0 if (out4_assets_house == .  | out4_assets_house == .m) & participation_alum == 1
lab var out4_assets_house "Value of House"

gen out4_assets_furniture = e36_c if participation_alum == 1
replace out4_assets_furniture = 0 if (out4_assets_furniture == .  | out4_assets_furniture == .m) & participation_alum == 1
lab var out4_assets_furniture "Value of Furniture"

gen out4_assets_machine = e37_c if participation_alum == 1
replace out4_assets_machine = 0 if (out4_assets_machine == . | out4_assets_machine == .m) & participation_alum == 1
lab var out4_assets_machine "Value of Machinery/Equipment"

gen out4_assets_stock = e38_c if participation_alum == 1
replace out4_assets_stock = 0 if (out4_assets_stock == . | out4_assets_stock == .m) & participation_alum == 1
lab var out4_assets_stock "Value of Stock"

gen out4_assets_other = e39_c if participation_alum == 1
replace out4_assets_other = 0 if (out4_assets_other == .  | out4_assets_other == .m) & participation_alum == 1
lab var out4_assets_other "Value of Other Assets"

local business_assets out4_assets_land out4_assets_house out4_assets_furniture out4_assets_machine out4_assets_stock out4_assets_other

/*******************************************************************************
			Outcome 6: Education and Wage Activity (Income Generating Activites)
*******************************************************************************/

**Dummy if currently in education
gen out6_education = (c7_c == 1) if participation_alum == 1
lab var out6_education "Currently in education"

**Dummy if in education in the past 12 months 
gen out6_edu_12 = .
forvalues x = 1(1)4{
	replace out6_edu_12 = (((date - c8_h3_`x'_c)/(365/12)) <= 12) if out6_edu_12 != 1 & participation_alum == 1 & (c8_f_`x'_c < date & c8_f_`x'_c != .)

}		// replace with 1 if in education in the past 12 months ()
lab var out6_edu_12 "In education in the past 12 months"

**Highest Level of education attended - Individual
gen out6_educ_S1 = (c1_3_c == 1) if participation_alum == 1
lab var out6_educ_S1 "S1"

gen out6_educ_S2 = (c1_3_c == 2) if participation_alum == 1
lab var out6_educ_S2 "S2"

gen out6_educ_S3 = (c1_3_c == 3) if participation_alum == 1
lab var out6_educ_S3 "S3"

gen out6_educ_S4 = (c1_3_c == 4) if participation_alum == 1
lab var out6_educ_S4 "S4"

gen out6_educ_S5 = (c1_3_c == 5) if participation_alum == 1
lab var out6_educ_S5 "S5"

gen out6_educ_S6 = (c1_3_c == 6) if participation_alum == 1
lab var out6_educ_S6 "S6"

gen out6_educ_attter = ((c1_3_c>= 7 & c1_3_c <= 9)|c1_3_c == 13) if participation_alum == 1
lab var out6_educ_attter "Attended Tertiary"

gen out6_educ_cert = (c1_3_c== 10) if participation_alum == 1
lab var out6_educ_cert "Certificate"

gen out6_educ_dip = (c1_3_c== 11 | c1_3_c== 12) if participation_alum == 1
lab var out6_educ_dip "Diploma"

gen out6_educ_comter = ((c0_c>=7 & c0_c<=9)|c0_c == 13) if participation_alum == 1
lab var out6_educ_comter "Completed Tertiary"

local educ_vars_i out6_educ_S1 out6_educ_S2 out6_educ_S3 out6_educ_S4 out6_educ_S5 out6_educ_S6 out6_educ_attter out6_educ_cert out6_educ_dip out6_educ_comter

**Level of education - Mutually exclusive 
gen out6_educ_ter = ((c1_3_c>=7 & c1_3_c<=9)|c1_3_c == 13) if participation_alum == 1
lab var out6_educ_ter "Any Tertiary"

gen out6_educ_sen = ((c1_3_c ==5 | c1_3_c ==6 /* |c1_3_c == 11 | c1_3_c == 12 */) /* | out6_educ_ter == 1 */) if participation_alum == 1  // Completing senior secodary education is necessary to attend tertiary education
lab var out6_educ_sen "Senior Secondary"

gen out6_educ_low = (((c1_3_c>0 & c1_3_c<=4)/* |c1_3_c == 10 */) /* | out6_educ_sen == 1 */) if participation_alum == 1  // Completing lower secondary education is necessary to attend senior secondary education
lab var out6_educ_low "Lower Secondary"

/*
gen out6_educ_cert = (c1_3_c == 10) if participation_alum == 1  
lab var out6_educ_cert "Certificate"

gen out6_educ_dip = (c1_3_c == 11 | c1_3_c == 12) if participation_alum == 1  
lab var out6_educ_dip "Diploma"
*/

gen 	out6_educ_level = 1 if out6_educ_low == 1 & participation_alum == 1
replace out6_educ_level = 2 if out6_educ_sen == 1 & participation_alum == 1
replace out6_educ_level = 3 if out6_educ_ter == 1 & participation_alum == 1
replace out6_educ_level = 4 if out6_educ_cert == 1 & participation_alum == 1
replace out6_educ_level = 5 if out6_educ_dip == 1 & participation_alum == 1
label define out6_educ_level 1 "Lower Secondary" 2 "Senior Secondary" 3 "Any Tertiary" 4 "Certificate" 3 "Diploma"
label values out6_educ_level out6_educ_level

gen out6_uace_sat = year(c4_20_c)
lab var out6_uace_sat "Sat for UACE"

local educ_vars out6_educ_low out6_educ_sen out6_educ_ter out6_educ_level out6_uace_sat


********************************************************************************
*								Wage activity								   *
********************************************************************************
**Dummy if participating in wage activity
gen out6_wage_activity = e1_1_c
lab var out6_wage_activity "Works for pay"

**Updating numbers of months worked from 0 to 1 if the numbers of days worked in a typical months is > 20
forvalues x = 1(1)4{
	replace e3_d_`x'_c = 1 if e2_e_`x'_c >= 20 & e3_d_`x'_c == 0  & participation_alum == 1
} 


**Dummy if worked in the past 12 months 
gen out6_wage_act_12 = ((e3_d_1_c > 0 & e3_d_1_c!= . & e3_d_1_c!= .m ) | (e3_d_2_c > 0 & e3_d_2_c!= . & e3_d_2_c!= .m) | (e3_d_3_c > 0 & e3_d_3_c!= . & e3_d_3_c!= .m) | (e3_d_4_c > 0 & e3_d_4_c!= . & e3_d_4_c!= .m)) if participation_alum == 1
lab var out6_wage_act_12 "Work for pay"


**Mututally exclusive groups 
gen out6_time_work_ME = (out6_wage_act_12 == 1 & out6_edu_12 == 0) if participation_alum == 1
lab var out6_time_work_ME "Work"
gen out6_time_study_ME = (out6_wage_act_12 == 0 & out6_edu_12 == 1) if participation_alum == 1
lab var out6_time_study_ME "Study"
gen out6_time_both_ME = (out6_wage_act_12 == 1 & out6_edu_12 == 1) if participation_alum == 1
lab var out6_time_both_ME "Both"
gen out6_time_neither_ME = (out6_wage_act_12 == 0 & out6_edu_12 == 0) if participation_alum == 1
lab var out6_time_neither_ME "Neither"

**Income from wage activities
forvalues x = 1(1)4{
	gen out6_totalearnings_`x' = e2_h_`x'_c/e3_d_`x'_c if participation_alum == 1
	replace out6_totalearnings_`x' = 0 if e2_h_`x'_c == 0 | e3_d_`x'_c == 0		// monthly income should include if worked for 1 month or more
	lab var out6_totalearnings_`x' "Average monthly earnings `x'"
}

egen out6_totalearnings 	= rowtotal(out6_totalearnings_1 out6_totalearnings_2 out6_totalearnings_3 out6_totalearnings_4), missing
replace out6_totalearnings = 0 if out6_totalearnings == . & out6_wage_activity == 0 & participation_alum == 1		// no earnings if not wage activity
lab var out6_totalearnings "Average monthly earnings in past 12 months"

egen out6_totalearnings_c 	= rowtotal(out6_totalearnings_1 out6_totalearnings_2 out6_totalearnings_3 out6_totalearnings_4), missing 
lab var out6_totalearnings_c "Average monthly earnings in past 12 months"		// conditional on wage activity

egen out6_earnings_day	= rowtotal(e2_j_a_1_c e2_j_a_2_c e2_j_a_3_c), missing		//e2_j_a_4: no observations 
replace out6_earnings_day = 0 if out6_totalearnings == . & participation_alum == 1
lab var out6_earnings_day "Average earnings in a day"

gen out6_earnings_day_year = out6_earnings_day*365 		if out6_earnings_day != .	// Sanity Check

egen out6_earnings_week	= rowtotal(e2_j_b_1_c e2_j_b_2_c), missing					//e2_j_b_3_c e2_j_b_4_c: no observations
lab var out6_earnings_week "Average earnings in a week"

gen out6_earnings_week_year = out6_earnings_week*52	 	if out6_earnings_week != . 	// Sanity Check

egen out6_earnings_month	= rowtotal(e2_j_c_1_c e2_j_c_2_c e2_j_c_3_c e2_j_c_4_c), missing
replace out6_earnings_month = 0 if out6_earnings_month == . & participation_alum == 1
lab var out6_earnings_month "Average earnings in a month"
gen out6_earnings_month_year = out6_earnings_month*12	if out6_earnings_month != . 	// Sanity Check

**Daily/weekly, monthly and 'by piece' wages converted to monthly income
forvalues i = 1(1)4{				// accounting for some variable swith no observations 
	gen 	out6_earn_month`i'_c = . 
	capture: replace out6_earn_month`i'_c = e2_j_a_`i'_c*e3_d_`i'_c 	if `i' != 4 & e2_i_`i'_c == 1 & participation_alum == 1  // if daily wage earners
	capture: replace out6_earn_month`i'_c = e2_j_b_`i'_c*4 			if (`i' != 3 | `i' != 4) & e2_i_`i'_c == 2 & participation_alum == 1  // if weekly wage earners
	capture: replace out6_earn_month`i'_c = e2_j_c_`i'_c	 			if e2_i_`i'_c == 3 & participation_alum == 1  // if monthly wage earners
	capture: replace out6_earn_month`i'_c = e2_k_`i'_c		 		if `i' != 4 & e2_i_`i'_c == 4 & participation_alum == 1  // if irregular wage earners
	capture: replace out6_earn_month`i'_c = e2_l1_`i'_c*e2_l2_`i'_c	if (`i' != 3 | `i' != 4) & e2_i_`i'_c == 5 & participation_alum == 1  // if earning by piece
}
egen out6_earn_month_c = rowtotal(out6_earn_month1_c out6_earn_month2_c out6_earn_month3_c out6_earn_month4_c), missing 			// conditional on working
lab var out6_earn_month_c "Average earnings in a month"

gen out6_earn_month = out6_earn_month_c			
replace out6_earn_month = 0 if out6_earn_month_c == . & participation_alum == 1  // unconditional on working
lab var out6_earn_month "Average earnings in a month"


**Benefits from wage activity
**Monthly
forvalues x = 1(1)4{
	gen out6_benefits_mth_`x' = e2_n_`x'_c if participation_alum == 1
	lab var out6_benefits_mth_`x' "Monthly value of benefits `x'"
}
egen out6_benefits_mth =  rowtotal(out6_benefits_mth_1 out6_benefits_mth_2 out6_benefits_mth_3 out6_benefits_mth_4), missing
replace out6_benefits_mth = 0 if out6_benefits_mth == . & out6_wage_activity == 0 & participation_alum == 1 & out6_wage_act_12 == 1	// no benefits if not wage activity
lab var out6_benefits_mth "Monthly Value of benefits"		// unconditional on wage activity

egen out6_benefits_mth_c =  rowtotal(out6_benefits_mth_1 out6_benefits_mth_2 out6_benefits_mth_3 out6_benefits_mth_4) if out6_wage_act_12 == 1 & participation_alum == 1 
lab var out6_benefits_mth_c "Monthly Value of benefits"  // conditional on wage activity

**Annual
forvalues x = 1(1)4{
	gen out6_benefits_`x' = e2_n_`x'_c*e3_d_`x'_c if participation_alum == 1 & e3_d_`x'_c >= 1 & out6_wage_act_12 == 1
	lab var out6_benefits_`x' "Yearly value of benefits `x'"
}
egen out6_benefits =  rowtotal(out6_benefits_1 out6_benefits_2 out6_benefits_3 out6_benefits_4), missing
replace out6_benefits = 0 if out6_benefits == . & out6_wage_activity == 0 & participation_alum == 1 	// no benefits if not wage activity
lab var out6_benefits "Yearly Value of benefits"		// unconditional on wage activity

egen out6_benefits_c =  rowtotal(out6_benefits_1 out6_benefits_2 out6_benefits_3 out6_benefits_4 )
lab var out6_benefits_c "Yearly Value of benefits"  // conditional on wage activity

**Payment in cash and in kind
**Monthly 
egen out6_pay_mth = rowtotal(out6_earn_month out6_benefits_mth), missing
lab var out6_pay_mth "Monthly Compensation (Salary and in-kind)"		// unconditional on wage activity

egen out6_pay_mth_c = rowtotal(out6_earn_month_c out6_benefits_mth_c), missing
lab var out6_pay_mth_c "Monthly Compensation (Salary and in-kind)"			// conditional on wage activity

**Average monthly
egen out6_pay = rowtotal(out6_totalearnings out6_benefits_mth), missing
replace out6_pay = 0 if out6_pay == . & out6_wage_activity == 0 & participation_alum == 1		// no earnings if not wage activity
lab var out6_pay "Average Monthly Compensation (Salary and in-kind)"		// unconditional on wage activity

egen out6_pay_c = rowtotal(out6_totalearnings_c out6_benefits_mth_c), missing
lab var out6_pay_c "Average Monthly Compensation (Salary and in-kind)"			// conditional on wage activity

**Dummy for full time jobs - atleast 1 full time job - FIXMERA
gen out6_fulltime_c = ((e2_e_1_c != . & e2_e_1_c >15 & e2_f_1_c > 5 ) | (e2_e_2_c != . & e2_e_2_c >15 & e2_f_2_c > 5) | (e2_e_3_c != . & e2_e_3_c >15 & e2_f_3_c > 5) | (e2_e_4_c != . & e2_e_4_c >15 & e2_f_4_c > 5)) if participation_alum == 1 & out6_wage_activity == 1		// conditional on wage activity
lab var out6_fulltime_c "Full time work"

gen out6_fulltime = ((e2_e_1_c != . & e2_e_1_c >15 & e2_f_1_c > 5 ) | (e2_e_2_c != . & e2_e_2_c >15 & e2_f_2_c > 5) | (e2_e_3_c != . & e2_e_3_c >15 & e2_f_3_c > 5) | (e2_e_4_c != . & e2_e_4_c >15 & e2_f_4_c > 5)) if participation_alum == 1 /* & out6_wage_activity == 1*/
replace out6_fulltime = 0 if out6_wage_activity == 0  // unconditional on wage activity
lab var out6_fulltime "Full time work"

**Dummy for formal (contract) work - atleast 1 formal contract
gen out6_contract = (e2_s_1_c == 1 | e2_s_2_c == 1 | e2_s_3_c == 1 | e2_s_4_c== 1) if participation_alum == 1 /* & out6_wage_activity == 1*/
replace out6_contract = 0 if out6_wage_activity == 0  
lab var out6_contract "Signed a contract"

**Dummy for if the applicant has ever interned 
gen out6_intern = (e2_t_1_c == 3 | e2_t_2_c == 3 | e2_t_4_c == 3 | e2_t_3== 3 | c8_10_c == 1 | c8_11_c == 1)
lab var out6_intern "Apprenticeship"

**Time worked - post last education
egen out6_lastedu_att = rowmax(c8_h3_1_c c8_h3_2_c c8_h3_3_c c8_h3_4_c) if participation_alum == 1
format out6_lastedu_att %td

egen out6_lastedu_att_incomplete = rowmax(c8_f_1_c c8_f_2_c c8_f_3_c c8_f_4_c) if participation_alum == 1
format out6_lastedu_att_incomplete %td

replace out6_lastedu_att = out6_lastedu_att_incomplete if out6_lastedu_att == . & participation_alum == 1
lab var out6_lastedu_att "Latest education attended" 

egen out6_worktime_date = rowmax(out6_lastedu_att e1_2_c) if participation_alum == 1
replace out6_worktime_date = e1_2_c if out6_worktime_date > date
format out6_worktime_date %td

gen out6_worktime = (date - out6_worktime_date)/(365/12) if participation_alum == 1
lab var out6_worktime "Months Worked"

local wage_activity_vars out6_wage_activity out6_pay out6_fulltime out6_contract out6_intern out6_worktime 
swindex `wage_activity_vars', normby(C_0) gen(index_wage_activity)	
lab var index_wage_activity "Wage Activity Index"

/*******************************************************************************
							Outcome 6: Business
*******************************************************************************/
gen out6_ownbusiness = (e15_c == 1) if participation_alum == 1
lab var out6_ownbusiness "Runs a business"

gen out6_ownbusiness_12 = ((e21_1_c > 0 & e21_1_c!= . & e21_1_c!= .m ) | (e21_2_c > 0 & e21_2_c!= . & e21_2_c!= .m)) if participation_alum == 1
lab var out6_ownbusiness_12 "Business in the past 12 months"

gen out6_numactivites = e16_c
replace out6_numactivites = 0 if out6_ownbusiness == 0
lab var out6_numactivites "Number of business activities"

egen out6_monthlyprofit = rowtotal(e24_1_c e24_2_c), missing		// sum of profits from all businesses 
replace out6_monthlyprofit = 0 if out6_ownbusiness == 0
lab var out6_monthlyprofit "Profit in a month"

forvalues x = 1(1)2{
	gen out6_avg_profit`x' = e25_`x'_c/e21_`x'_c if participation_alum == 1 & out6_ownbusiness == 1
	lab var out6_avg_profit`x' "Averge monthly profit `x'"
}

egen out6_avg_profit = rowtotal(out6_avg_profit1 out6_avg_profit2), missing		// sum of profits from all businesses 
replace out6_avg_profit = 0 if out6_ownbusiness == 0
lab var out6_avg_profit "Average monthly profit"

egen out6_avg_profit_c = rowtotal(out6_avg_profit1 out6_avg_profit2), missing		// sum of profits from all businesses 
lab var out6_avg_profit_c "Average monthly profit"

gen out6_monthlyhrs = e23_1_c*e22_1_c		// no of hrs worked in a day x no of days worked in a month 
replace out6_monthlyhrs = 0 if out6_ownbusiness == 0
lab var out6_monthlyhrs "Hours worked in a month"

/*
. list e23_1_c e23_2_c e22_1_c e22_2_c e21_1_c e21_2_c if e16_c == 2

      +-----------------------------------------------------------+
      | e23_1_c   e23_2_c   e22_1_c   e22_2_c   e21_1_c   e21_2_c |
      |-----------------------------------------------------------|
   3. |      11        11        20        20        12         8 |
 714. |      10        10        28        28         4         4 |
      +-----------------------------------------------------------+

*/

gen out6_totalhrs = e23_1_c*e22_1_c*e21_1_c		// no of hrs worked in a day x no of days worked in a month x no of months worked in an year
replace out6_totalhrs = 0 if out6_ownbusiness == 0
lab var out6_totalhrs "Hours worked in an year"

local business_vars out6_ownbusiness out6_numactivites out6_monthlyprofit out6_avg_profit out6_monthlyhrs out6_totalhrs
swindex `business_vars', normby(C_0) gen(index_business)	
lab var index_business "Business Index"


**Earning in  a year - from wage activity and Business profits 
**egen out6_income = rowtotal(out6_pay out6_avg_profit) if participation_alum == 1

egen out6_income = rowtotal(out6_pay out6_avg_profit) if participation_alum == 1


/*******************************************************************************
							Outcome 6: Any income activity
*******************************************************************************/
gen out6_inc_activity = (out6_wage_activity == 1 | out6_ownbusiness == 1) if participation_alum == 1
lab var out6_inc_activity "IGA"   	// Currently in an income generating activity - wage or business 

**Skilled work - for those currently in a wage activity ot business 
gen out6_inc_skilled_wage_1 = .
gen out6_inc_skilled_wage_2 = .
gen out6_inc_skilled_wage_3 = .
gen out6_inc_skilled_wage_4 = .

forvalues x = 1(1)4{
    lab var out6_inc_skilled_wage_`x' "Skilled Activity"  
	replace out6_inc_skilled_wage_`x' = ((e2_b_`x'_c >=  13 & e2_b_`x'_c <=  19) | e2_b_`x'_c == 22 /* | e2_b_`x'_c == 25 */) if participation_alum == 1 & out6_wage_activity == 1
}

gen out6_inc_skilled_wage = (out6_inc_skilled_wage_1 == 1 | out6_inc_skilled_wage_2 == 1 | out6_inc_skilled_wage_3 == 1 | out6_inc_skilled_wage_4 == 1) if participation_alum == 1 & out6_wage_activity == 1
lab var out6_inc_skilled_wage "Skilled Activity"

gen out6_inc_skilled_biz = (e17_13_c == 1 | e17_14_c == 1 | e17_15_c == 1 | e17_22_c == 1 /* | e17_25_c == 1 */) if participation_alum == 1 & out6_ownbusiness == 1
lab var out6_inc_skilled_biz "Skilled Business"

gen out6_inc_skilled = (out6_inc_skilled_wage == 1 | out6_inc_skilled_biz == 1) if participation_alum == 1 & out6_inc_activity == 1
lab var out6_inc_skilled "Skilled"

**Mutually exclusive groups - CURRENTLY
gen out6_inc_activity_ME =  (out6_inc_activity == 1 & out0_enrolledschool == 0)
lab var out6_inc_activity_ME "Working"
gen out6_inc_study_ME =  (out6_inc_activity == 0 & out0_enrolledschool == 1)
lab var out6_inc_study_ME "Studying"
gen out6_inc_both_ME =  (out6_inc_activity == 1 & out0_enrolledschool == 1)
lab var out6_inc_both_ME "Both"
gen out6_inc_neither_ME =  (out6_inc_activity == 0 & out0_enrolledschool == 0)
lab var out6_inc_neither_ME "Neither"

gen out6_inc_activity_12 = (out6_wage_act_12 == 1 | out6_ownbusiness_12 == 1) if participation_alum == 1
lab var out6_inc_activity_12 "IGA"   	// Currently in an income generating activity - wage or business 

**Mututally exclusive groups - IN THE LAST 12 MONTHS
gen out6_inc_act_12_ME = (out6_inc_activity_12 == 1 & out6_edu_12 == 0) if participation_alum == 1
lab var out6_inc_act_12_ME "Work"
gen out6_inc_study_12_ME = (out6_inc_activity_12 == 0 & out6_edu_12 == 1) if participation_alum == 1
lab var out6_inc_study_12_ME "Study"
gen out6_inc_both_12_ME = (out6_inc_activity_12 == 1 & out6_edu_12 == 1) if participation_alum == 1
lab var out6_inc_both_12_ME "Both"
gen out6_inc_nth_12_ME = (out6_inc_activity_12 == 0 & out6_edu_12 == 0) if participation_alum == 1
lab var out6_inc_nth_12_ME "Neither"

**Self-employed
forvalues x = 1(1)4{
	gen out6_inc_selfemployed_`x' = .
    lab var out6_inc_selfemployed_`x' "Self-Employed"  
	replace out6_inc_selfemployed_`x' = (e2_b_`x'_c == 1 /*HOUSEWIFE*/ ///
		| e2_b_`x'_c == 2 /*CULTIV OWN CONS*/ | e2_b_`x'_c == 4 /*AGRI DAY LABOR*/ ///
		| e2_b_`x'_c == 5 /*DAY LABOR*/ 		| e2_b_`x'_c == 6 /*FACTORY*/ ///
		| e2_b_`x'_c == 7/*ANIMAL OWN CONS*/ |e2_b_`x'_c == 9 /*SERVANT*/ ///
		| e2_b_`x'_c == 11 /*SHOP WORKER*/ 	| e2_b_`x'_c == 14 /*TEACHER*/ ///
		| e2_b_`x'_c == 15 /*PROFESSIONAL*/ 	| e2_b_`x'_c == 16 /*MANAGER*/ ///
		| e2_b_`x'_c == 17 /*CLERK*/ 		| e2_b_`x'_c == 18 /*MANAGER GOVT*/ ///
		| e2_b_`x'_c == 19 /*CLERK GOVT*/ 	| e2_b_`x'_c == 20 /*POLITICIAN*/ ///
		| e2_b_`x'_c == 21 /*PASTOR*/  		| e2_b_`x'_c == 33 /*OTHER SALARIED ACTIVITY*/ ///
		| e2_b_`x'_c == 30 /*STUDENT*/) if participation_alum == 1 & out6_wage_act_12 == 1
}
gen out6_inc_selfemployed = (out6_inc_selfemployed_1 == 1 | out6_inc_selfemployed_2 == 1 | out6_inc_selfemployed_3 == 1 | out6_inc_selfemployed_4 == 1) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_selfemployed "Self-Employed"  

**Skilled work in the last 12 months 
forvalues x = 1(1)4{
	gen out6_inc_skilled_wage_`x'_12 = .
    lab var out6_inc_skilled_wage_`x'_12 "Skilled Activity"  
	replace out6_inc_skilled_wage_`x'_12 = ((e2_b_`x'_c >=  13 & e2_b_`x'_c <=  19) | e2_b_`x'_c == 22 /* | e2_b_`x'_c == 25 */) if participation_alum == 1 & out6_wage_act_12 == 1
}

gen out6_inc_skilled_wage_12 = (out6_inc_skilled_wage_1_12 == 1 | out6_inc_skilled_wage_2_12 == 1 | out6_inc_skilled_wage_3_12 == 1 | out6_inc_skilled_wage_4_12 == 1) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_skilled_wage_12 "Skilled Activity"

gen out6_inc_gov_1  = .
gen out6_inc_gov_2 = .
gen out6_inc_gov_3 = .
gen out6_inc_gov_4 = .

forvalues x = 1(1)4{
    lab var out6_inc_gov_`x' "Public Sector"  
	replace out6_inc_gov_`x' = (e2_b_`x'_c ==  14 | e2_b_`x'_c ==  18 | e2_b_`x'_c == 19 | e2_b_`x'_c == 20 | e2_b_`x'_c == 22) if participation_alum == 1 & out6_wage_act_12 == 1
}

gen out6_inc_gov = (out6_inc_gov_1 == 1 | out6_inc_gov_2 == 1 | out6_inc_gov_3 == 1 | out6_inc_gov_4 == 1) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_gov "Public Sector"


forvalues x = 1(1)4{
    gen out6_inc_nonmanual_`x'  = .
	lab var out6_inc_nonmanual_`x' "Non-Manual Wage"  
	replace out6_inc_nonmanual_`x' = ((e2_b_`x'_c >=  14 & e2_b_`x'_c <=  22) | (e2_b_`x'_c >=  30 & e2_b_`x'_c <=  32)) if participation_alum == 1 & out6_wage_act_12 == 1
}

gen out6_inc_nonmanual_wage = (out6_inc_nonmanual_1 == 1 | out6_inc_nonmanual_2 == 1 | out6_inc_nonmanual_3 == 1 | out6_inc_nonmanual_4 == 1) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_nonmanual_wage "Non-Manual Wage"


gen out6_inc_skilled_biz_12 = (e17_13_c == 1 | e17_14_c == 1 | e17_15_c == 1 | e17_22_c == 1 /* | e17_25_c == 1 */) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_skilled_biz "Skilled Business"

gen out6_inc_skilled_12 = (out6_inc_skilled_wage == 1 | out6_inc_skilled_biz == 1) if participation_alum == 1 & out6_inc_activity_12 == 1
lab var out6_inc_skilled_12 "Skilled" // in the last 12 months 

gen out6_inc_nonmanual_biz_12 = (e17_12_c == 1 | e17_14_c == 1 | e17_15_c == 1 | e17_21_c == 1 | e17_22_c == 1 | e17_29_c == 1 | e17_31_c == 1 | e17_32_c == 1) if participation_alum == 1 & out6_wage_act_12 == 1
lab var out6_inc_nonmanual_biz_12 "Non-Manual Business"

gen out6_inc_nonmanual = (out6_inc_nonmanual_wage == 1 | out6_inc_nonmanual_biz_12 == 1) if participation_alum == 1 & out6_inc_activity_12 == 1
lab var out6_inc_nonmanual "White Collar" // in the last 12 months 

gen out6_intern_12 = (e2_t_1_c == 3 | e2_t_2_c == 3 | e2_t_4_c == 3 | e2_t_3== 3 | c8_10_c == 1 | c8_11_c == 1) if participation_alum == 1 /* & out6_wage_act_12 == 1
*/
lab var out6_intern_12 "Apprenticeship"

**Income: form wage generating activities and/or business 
egen out6_avg_inc = rowtotal(out6_avg_profit out6_pay)  if participation_alum == 1 & out6_inc_activity_12 == 1
replace out6_avg_inc = 0 if out6_avg_inc == . & participation_alum == 1
lab var out6_avg_inc "Monthly income"  // unconditional

egen out6_mon_inc = rowtotal(out6_monthlyprofit out6_pay_c) if participation_alum == 1 & out6_inc_activity_12 == 1
lab var out6_mon_inc "Monthly income"

egen out6_avg_inc_c = rowtotal(out6_pay_c out6_avg_profit_c) if participation_alum == 1 & out6_inc_activity_12 == 1
lab var out6_avg_inc_c "Monthly income"

egen out6_inc_month = rowtotal(e21_1_c e21_2_c e3_d_1_c e3_d_2_c e3_d_3_c e3_d_4_c), missing
replace out6_inc_month = 12 if out6_inc_month >= 12 & out6_inc_month != .  // working on multiple jobs  that it adds up to more than 12: (25 real changes made)
replace out6_inc_month = . if participation_alum == 1 & out6_inc_activity_12 == 0  // 3 moved to missing - no months worked if not wokring in the last 12 months
lab var out6_inc_month "Months worked"

/*******************************************************************************
							Outcome 19: Aspirations
*******************************************************************************/
 
**Aspirations 
gen out19_asp_job = e6_1_c if participation_alum == 1
lab var out19_asp_job "Work in job"

gen out19_asp_biz = e6_2_c if participation_alum == 1
lab var out19_asp_biz "Run a business"

gen out19_asp_fam = e6_3_c if participation_alum == 1
lab var out19_asp_fam "Care for family"

**Education needed
gen out19_educ_none = (e7_c == 0) if participation_alum == 1
lab var out19_educ_none "None"

gen out19_educ_low = (e7_c >=1 & e7_c <= 4) if participation_alum == 1
lab var out19_educ_low "Lower Secondary"

gen out19_educ_sen = (e7_c >=5 & e7_c <= 6) if participation_alum == 1
lab var out19_educ_sen "Senior Secondary"

gen out19_educ_ter = ((e7_c >=7 & e7_c <= 9) | e7_c == 13) if participation_alum == 1
lab var out19_educ_ter "Tertiary"

gen out19_educ_cert = (e7_c == 10) if participation_alum == 1
lab var out19_educ_cert "Certificate"

gen out19_educ_dip = (e7_c >=11 & e7_c <= 12) if participation_alum == 1
lab var out19_educ_dip "Diploma"

**Constraints
gen out19_asp_constraint = e8_c if participation_alum == 1
label define cons 0 "No Constraint" 1 "Education/Skills" 2 "Money" 3 "Permission" 4 "Lack of Support" 5 "Lack of Determination" 88 "Other"
label value out19_asp_constraint cons

gen out19_cons_none = (e8_c == 0) if participation_alum == 1
lab var out19_cons_none "None"

gen out19_cons_edu = (e8_c == 1) if participation_alum == 1
lab var out19_cons_edu "Education"

gen out19_cons_money = (e8_c == 2) if participation_alum == 1
lab var out19_cons_money "Money"

gen out19_cons_perm = (e8_c == 3) if participation_alum == 1
lab var out19_cons_perm "Permission"

gen out19_cons_sup = (e8_c == 4) if participation_alum == 1
lab var out19_cons_sup "Support"

gen out19_cons_deter = (e8_c == 5) if participation_alum == 1
lab var out19_cons_deter "Determination"

gen out19_cons_oth = (e8_c == 6) if participation_alum == 1
lab var out19_cons_oth "Other"





/*******************************************************************************
							Outcome 11: Use of Time
*******************************************************************************/
	
gen out11_time_school = e4a_c
lab var out11_time_school "School/ Training/ Apprenticeship"
	
gen out11_time_study = e4b_c
lab var out11_time_study "Homework"

egen out11_time_familywork = rowtotal(e4c_c e4d_c), missing
lab var out11_time_familywork "Family shop/business/income generating activity"

gen out11_time_work_out = e4f_c
lab var out11_time_work_out "Work outside household"

egen out11_time_work = rowtotal(out11_time_familywork out11_time_work_out), missing 
lab var out11_time_work "Working (any)"

egen out11_time_domesticwork = rowtotal(e4g_c e4i_c), missing			// domestic chores + taking care of family 
lab var out11_time_domesticwork "Domestic work"
	
gen out11_unpaidwork_out =  	e4e_c		// FIXMEBL: added as suggestion 
lab var out11_unpaidwork_out "Unpaid work outside household"
	
gen out11_time_sleep = e4h_c
lab var out11_time_sleep "Sleep"
	
egen out11_unpaidwork = rowtotal(out11_time_domesticwork out11_unpaidwork_out), missing 
lab var out11_unpaidwork "Unpaid work"
lab var out11_unpaidwork_out "Unpaid work outside household"

**Sanity check - FYI: not all adding upto 24 hours for all 
egen total_time = rowtotal(out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep)


local time_vars out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep
swindex `time_vars', normby(C_0) gen(index_timeuse)	
lab var index_timeuse "Use of Time Index"

/*******************************************************************************
			Outcome 12: Cognitive Function and Education Competencies
*******************************************************************************/
** RAW SCORE 
/*
	def: Points were awarded for each list correctly repeated with no partial credit.
	ref: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3434463/
	
	The total Digit Span raw score, which is based on the sum of the Digits Forward and Digits Backward raw scores
*/
	
	* total raw forward score 
	egen out12_dight_fwd_raw_score 	= rowtotal(	j1a_c j1b_c j2a_c j2b_c j3a_c j3b_c ///
												j4a_c j4b_c j5a_c j5b_c j6a_c j6b_c ///
												j7a_c j7b_c), missing
	lab var out12_dight_fwd_raw_score "Digit Span Forward Score (raw) [0-14]"
	
	* Standardize and label
	egen out12_dight_fwd_raw_score_Z = std(out12_dight_fwd_raw_score)		// FIXMEBL: standardize this way or our way?
	label var out12_dight_fwd_raw_score_Z "Digit span score - F"

	
	* total raw backward score 
	egen out12_dight_bkwd_raw_score 	= rowtotal(	j8a_c j8b_c j9a_c j9b_c j10a_c j10b_c ///
											j11a_c j11b_c j12a_c j12b_c j13a_c j13b_c ///
											j14a_c j14b_c) , missing
	lab var out12_dight_bkwd_raw_score "Digit Span Backward Score (raw) [0-14]"
	
	* Standardize and label
	egen out12_dight_bkwd_raw_score_Z = std(out12_dight_bkwd_raw_score)
	label var out12_dight_bkwd_raw_score_Z "Digit span score - B"
		
	* total overall score 
	egen out12_dight_tot_raw_score 	= rowtotal(out12_dight_fwd_raw_score out12_dight_bkwd_raw_score), missing
	lab var out12_dight_tot_raw_score "Digit Span Total Score (raw) [0-28]"
	
	* Standardize and label
	egen out12_dight_tot_raw_score_Z = std(out12_dight_tot_raw_score)
	label var out12_dight_tot_raw_score_Z "Digit span score - F&B"
	
	
	* longest length span scores
/*

	def: longest length span scores (longest digit list length correctly recalled) 
	when reporting separate results for the forward (Longest Digit Span Forward, LDSF) and backward (Longest Digit Span Backward, LDSB)
	ref: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3080130/#R47

*/

	* longest length span - forward 
	gen out12_digit_f = 2 if (j1a_c == 0 & j1b_c == 0) // assuming 2 if incorrect - Raaga's Notes: Since we start with a length of 3 digits
	lab var out12_digit_f "Longest Digit Span Forward"
	
	forvalue x = 1/7 {

		**local y = `x' + 2 // 1-9, should not get point if fail
		replace out12_digit_f = `x' + 2 if (j`x'a_c == 1 | j`x'b_c == 1) & out12_dight_fwd_raw_score != .		
	}

	* Standardize and label
	egen out12_digit_f_Z = std(out12_digit_f)
	label var out12_digit_f_Z "Longest Digit Span Forward"
	
	* longest length span - backward 
	gen out12_digit_b = 2 if (j8a_c == 0 & j8b_c == 0) // assuming 1 if incorrect
	lab var out12_digit_b "Longest Digit Span Backward"

	
	forvalue x = 8/14 {
		
		**local i = `x' - 5 // 1-8, should not get point if fail
		replace out12_digit_b = `x' - 5 if (j`x'a_c == 1 | j`x'b_c == 1) & out12_dight_bkwd_raw_score != .
	}	
	
	* Standardize and label
	egen out12_digit_b_Z = std(out12_digit_b)
	label var out12_digit_b_Z "Longest Digit Span Backward"
	
	* DS 	
	egen out12_digit_span 	= rowtotal(out12_digit_f out12_digit_b), missing
	lab var out12_digit_span "Longest Digit Span [0-17]"

	* Standardize and label
	egen out12_digit_span_Z = std(out12_digit_span)
	label var out12_digit_span_Z "Longest Digit Span- F&B"	

	* Reliable Digit Span (RDS)
/*
	Reliable Digit Span was calculated according to the guidelines recommended by Greiffenstein and colleagues (1994; sum of the longest string of digits repeated without error over two trials under both forward and backward conditions). 
	A score of 2 was assigned to individuals who failed at least one trial each of the floor items (two forward and two backward)
	ref: https://academic.oup.com/acn/article/26/5/377/4662
	ref: https://psycnet.apa.org/fulltext/1995-04039-001.pdf?auth_token=9906ce7add63a4379db1210d0764e0232a62756a
	
	For example, a client who passed both trials of three digits forward, passed both trials of two digits backward, but failed one trial each of four    	digits forward and three backward would earn an RDS score of 5. Subjects who failed at least one trial each of the floor items (three forward and two backward) were assigned an RDS score of 3.
*/
	
	* RDS - forward 
	forvalue x = 1/14 {
	    
		if `x' == 1 | `x' == 8{
		    
			gen out12_rds_p0`x' 	= 2					// Raaga's notes: Since the minimum number of digit span is 3
			replace out12_rds_p0`x' 	= .m if mi(j`x'a_c) | mi(j`x'b_c)	
			
		    gen out12_rds_p`x' 		= (j`x'a_c == 1 & j`x'b_c == 1)
			replace out12_rds_p`x' 	= .m if mi(j`x'a_c ) | mi(j`x'b_c)
			
		}
		else {
		    gen out12_rds_p`x' 		= (j`x'a_c  == 1 & j`x'b_c  == 1)
			replace out12_rds_p`x' 	= .m if mi(j`x'a_c ) | mi(j`x'b_c )
		}
		
		
	}
	
	egen out12_rds_fwd = rowtotal(out12_rds_p01 out12_rds_p1 out12_rds_p2 out12_rds_p3 out12_rds_p4 out12_rds_p5 out12_rds_p6 out12_rds_p7), missing
	lab var out12_rds_fwd "Reliable Digit Span: Forward [1-8]"
		
	* Standardize and label
	egen out12_rds_fwd_Z = std(out12_rds_fwd)
	label var out12_rds_fwd_Z "Reliable digit span - F"
	
	* RDS - backward 	
	egen out12_rds_bkwd = rowtotal(out12_rds_p08 out12_rds_p8 out12_rds_p9 out12_rds_p10 out12_rds_p11 out12_rds_p12 out12_rds_p13 out12_rds_p14), missing
	lab var out12_rds_bkwd "Reliable Digit Span: Backward [1-8]"
	
	* Standardize and label
	egen out12_rds_bkwd_Z = std(out12_rds_bkwd)
	label var out12_rds_bkwd_Z "Reliable digit span - B"	
	
	* RDS 	
	egen out12_rds 	= rowtotal(out12_rds_fwd out12_rds_bkwd), missing
	lab var out12_rds "Reliable Digit Span [0-16]"

	* Standardize and label
	egen out12_rds_Z = std(out12_rds)
	label var out12_rds_Z "Reliable digit span - F&B"	
	
	***************
	** R: Ravens **
	***************
	
	* RAVEN RAW SCORE
	// ref: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9290746/
	// ref: https://core.ac.uk/download/pdf/145054987.pdf (@ page 62)

	/*
	
	the 16th item in the test was a mistake	
	dropped that one in final raw score calulation
	did not use the SurveyCTO calculated one for individual test correct score
	
	*/
	* a. Number correctly answered
	gen ravens_correct1 = (j15_c == 8) if participation_alum == 1
	gen ravens_correct2 = (j16_c == 4) if participation_alum == 1
	gen ravens_correct3 = (j17_c == 5) if participation_alum == 1
	gen ravens_correct4 = (j18_c == 1) if participation_alum == 1
	gen ravens_correct5 = (j19_c == 2) if participation_alum == 1
	gen ravens_correct6 = (j20_c == 5) if participation_alum == 1
	gen ravens_correct7 = (j21_c == 6) if participation_alum == 1
	gen ravens_correct8 = (j22_c == 3) if participation_alum == 1
	gen ravens_correct9 = (j23_c == 7) if participation_alum == 1
	gen ravens_correct10 = (j24_c == 8) if participation_alum == 1
	gen ravens_correct11 = (j25_c == 7) if participation_alum == 1
	gen ravens_correct12 = (j26_c == 6) if participation_alum == 1	
	
	egen out12_ravens = rowtotal(ravens_correct1 ravens_correct2 ///
								ravens_correct3 ravens_correct4 ///
								ravens_correct5 ravens_correct6 ///
								ravens_correct7 ravens_correct8 ///
								ravens_correct9 ravens_correct10 ///
								ravens_correct11 ravens_correct12), missing
	lab var out12_ravens	"Raven's Progressive Matrices (RPM) [0-12]" // 0-15 
	
	* Standardize and label
	egen out12_ravens_Z = std(out12_ravens)
	label var out12_ravens_Z "RPM"	
	
	forvalue x = 15/26 {
	    
		gen ravens_attempted`x' = (j`x'_c != 99) if participation_alum == 1
	}
	
	*b. Number of attempted
	egen out12_ravens_attempted_raw = rowtotal(ravens_attempted15 ravens_attempted16 ///
										ravens_attempted17 ravens_attempted18 ///
										ravens_attempted19 ravens_attempted20 ///
										ravens_attempted21 ravens_attempted22 ///
										ravens_attempted23 ravens_attempted24 ///
										ravens_attempted25 ravens_attempted26), missing								
	lab var out12_ravens_attempted_raw 		"Numbers of attempted (raw) [0-15]" 
	
* Standardize and label
egen out12_ravens_attempted_raw_Z = std(out12_ravens_attempted_raw)
label var out12_ravens_attempted_raw_Z "RPM attempted"

local cognitive_vars out12_dight_fwd_raw_score out12_dight_bkwd_raw_score out12_dight_tot_raw_score out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_attempted_raw
swindex `cognitive_vars', normby(C_0) gen(index_cognitive)	
lab var index_cognitive "Cognitive Function and Education Competencies"

/*******************************************************************************
			Outcome 13: Psychological Skills
*******************************************************************************/
/*
gen out13_managesproblems = g1a_c
gen out13_determined = g1b_c
gen out13_accomplishsgoals = g1c_c
gen out13_confident = g1d_c
gen out13_resourcefull = g1e_c
gen out13_problemsolver = g1f_c
gen out13_composed = g1g_c
gen out13_analytical = g1h_c
gen out13_selfreliant = g1i_c
*/


local psych_skills g1a_c g1b_c g1c_c g1d_c g1e_c g1f_c g1g_c g1h_c g1i_c g1j_c

swindex `psych_skills', normby(C_0) gen(index_psych_skills)		
lab var index_psych_skills "Psychological Skills Index"

/*******************************************************************************
			Outcome 14: Self Esteem
*******************************************************************************/	
foreach var in g2b_c g2e_c g2f_c g2h_c g2i_c{
	replace `var' = 6 - `var' /*reverse coding and rescale*/  
	
		local variable: var label `var'
		label var `var' "`variable'*"
}

local self_esteem g2a_c g2b_c g2c_c g2d_c g2e_c g2f_c g2g_c g2h_c g2i_c g2j_c

swindex `self_esteem', normby(C_0) gen(index_self_esteem)		
lab var index_self_esteem "Self-Esteem Index"
	
/*******************************************************************************
			Outcome 15: Resilience 
*******************************************************************************/
local resilience g3a_c g3b_c g3c_c g3d_c g3e_c g3f_c g3g_c g3h_c g3i_c g3j_c g3k_c g3l_c g3m_c g3n_c g3o_c g3p_c g3q_c g3r_c g3s_c g3t_c g3u_c g3v_c g3w_c g3x_c g3y_c

swindex `resilience', normby(C_0) gen(index_resilience)		
lab var index_resilience "Resilience Index"


/*******************************************************************************
			Outcome 16: Attitude and Self Confidence
*******************************************************************************/
local attitude g3a1_c g3b1_c g3c1_c g3d1_c g3e1_c g3f1_c g3g1_c g3h1_c g3i1_c g3j1_c

swindex `attitude', normby(C_0) gen(index_attitude)		
lab var index_attitude "Attitude Index"

/*******************************************************************************
			Outcome 17: Risky Behavior
*******************************************************************************/
**Drinking
gen out17_drinking = i23_c if participation_alum == 1
lab var out17_drinking 		"Drink Alcohol" 

**Sexual Behavior
lab var i9_0_c 	"None" 
lab var i9_1_c	"Oral Contraceptive Pills"
lab var i9_2_c	"Injectables"
lab var i9_3_c	"Condoms"
lab var i9_4_c	"Emergency Contraceptive Pills"
lab var i9_5_c	"Implant"
lab var i9_88_c	"Other"


gen out17_contraceptives = 1 if (i6_c == 1 | i9_3_c == 1 | i9_1_c == 1 | i9_2_c == 1 | i9_3_c == 1 | i9_4_c == 1 | i9_5_c == 1) & participation_alum == 1	// any contraceptives
replace out17_contraceptives = 0 if ((i6_c == 0) | (i9_3_c ==0 & i9_1_c == 0 & i9_2_c == 0 & i9_3_c == 0 & i9_4_c == 0 & i9_5_c == 0)) & participation_alum == 1	// any contraceptives
lab var out17_contraceptives 		"Use Contraceptives" 

gen out17_transactionalsex = 1 if (i11_a_c == 1 | i11_b_c == 1) & participation_alum == 1
replace out17_transactionalsex = 0 if (i11_a_c == 0 & i11_b_c == 0) & participation_alum == 1
lab var out17_transactionalsex 		"Transactional Sex"

local risky_behavior out17_drinking out17_contraceptives  out17_transactionalsex

/*******************************************************************************
			Outcome 18: Fertility Choices
*******************************************************************************/

*Have children
gen out18_child = ((i13d_c>0 & i13d_c<5) | (i15b_c>0 & i15b_c<10)) if participation_alum == 1
lab var out18_child 		"Have Biological Children"

*No. of Children
gen out18_numchild = i13d_c if gender_app == 0 & participation_alum == 1
replace out18_numchild = i15b_c if gender_app == 1 & out18_numchild == . & participation_alum == 1 
replace out18_numchild = 0 if out18_child == 0 & participation_alum == 1  // zero children if you dont have children
lab var out18_numchild 		"Number of Children"

*Desired numbers of children
gen out18_numchild_d = i14c_c if gender_app == 0 & participation_alum == 1
replace out18_numchild_d = i16c_c if gender_app == 1 & participation_alum == 1 
/*
replace out18_numchild_d = 0 if (out18_numchild_d == . | out18_numchild_d == .r) &  participation_alum == 1 
*/
lab var out18_numchild_d	"Number of Children desired"

local fertility_vars out18_child out18_numchild out18_numchild_d

/*******************************************************************************
			Converting Money values
*******************************************************************************/
local 2022standardexchangerate	= 3689.82
local 2022PPPexchangerate		= 1278.43

local moneyvalues out6_pay out6_pay_c out6_pay_mth out6_pay_mth_c out6_monthlyprofit out6_avg_profit `business_assets' out6_income out6_avg_inc out6_avg_inc_c out6_mon_inc out6_inc_month

foreach monetaryvar in `moneyvalues'{
    
	di "`monetaryvar'"

	gen `monetaryvar'2022stex = .
	gen `monetaryvar'PPP_22 = .
	
	replace `monetaryvar'2022stex = (`monetaryvar'/`2022standardexchangerate') if baseline == 1 & ltfu == 1 
	
	replace `monetaryvar'PPP_22 = ( `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate')) 
	
	local variable: var label `monetaryvar'
	label var `monetaryvar'PPP_22 "`variable'"
	
}

		
/******************************************************************************/

*All indices
local indices index_scholarship index_wage_activity index_business index_cognitive index_timeuse index_psych_skills index_self_esteem index_resilience index_attitude survey_year_a

keep ///
/* Identifiers */ id_new baseline ltfu cohort2014 participation_alum  final_select NSC_final_select  sex_app gender_app notfoundatLTFU notfoundatFU C_0 T_0	NSC_intdcode survey_year ///
/* Outcome */ `indices' `scholarship_vars' `wage_activity_vars' `business_vars' `time_vars' `cognitive_vars' `psych_skills' `self_esteem' `resilience' `attitude'  `demographic_vars' `risky_behavior' `fertility_vars' `educ_vars' `educ_vars_i' ///
/*Money variables*/ out6_* out6_education out6_payPPP_22 out6_pay_cPPP_22 out6_monthlyprofitPPP_22 out6_avg_profitPPP_22 out4_assets_landPPP_22 out4_assets_housePPP_22 out4_assets_furniturePPP_22 out4_assets_machinePPP_22 out4_assets_stockPPP_22 out4_assets_otherPPP_22 out6_incomePPP_22 out6_fulltime_c out6_pay_mthPPP_22 out6_pay_mth_cPPP_22 time_use_* /* out6_time_*
*/ /* Demographics*/ out0_* ///
/* Aspirations */ out19_* out6_inc_activity_12 out6_wage_act_12 out6_inc_selfemployed out6_avg_incPPP_22 out6_avg_inc_cPPP_22 out6_inc_month out6_intern_12 out6_inc_nonmanual out6_inc_month out6_inc_monthPPP_22

save "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", replace

