
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Output/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1
	
	* Set local
	local educ_cat out19_asp_job out19_asp_biz out19_asp_fam 
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if _n == 1
				replace vars`var' = vars_treat`var' if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		

		* Create graphable dataset
		use `out19_asp_job', clear
			
		foreach var in out19_asp_biz out19_asp_fam {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") /* if var_T`var' >= 0.015 | var_T`var' <= -0.015
*/
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout19_asp_job counter if T_0==0 /* & var_name == "out19_asp_job" */, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_job counter if T_0==1 /* & var_name == "out19_asp_job" */, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///
					(scatter varsout19_asp_jobl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_job) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout19_asp_biz counter if T_0==0 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_biz counter if T_0==1 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout19_asp_bizl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_biz) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///									
				(bar varsout19_asp_fam counter if T_0==0 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_fam counter if T_0==1 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout19_asp_faml counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_fam) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout19_asp_job ubout19_asp_job counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_biz ubout19_asp_biz counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_fam ubout19_asp_fam counter if T_0 == 1,  lcolor(black)), ///	 ///
/*
			   xalternate yalternate */ ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(1.5 "Job" 4 "Business" 6.5 "Family") 		///
			   $TwowayBar
			   
			 graph export "$applicant_mast/Outputs/Figures/aspirations.png", replace
	
**Subsample: Women

version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

keep if gender_app == 0
	
	
/*
	* Specify variables
	gen vars_control = .
	gen vars_treat = .
	gen vars = .
	gen lb = .
	gen ub = .
	gen pval = .
*/
	
	* Set local
	local educ_cat out19_asp_job out19_asp_biz out19_asp_fam 
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if _n == 1
				replace vars`var' = vars_treat`var' if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		

		* Create graphable dataset
		use `out19_asp_job', clear
			
		foreach var in out19_asp_biz out19_asp_fam {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") /* if var_T`var' >= 0.015 | var_T`var' <= -0.015
*/
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout19_asp_job counter if T_0==0 /* & var_name == "out19_asp_job" */, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_job counter if T_0==1 /* & var_name == "out19_asp_job" */, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///
					(scatter varsout19_asp_jobl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_job) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout19_asp_biz counter if T_0==0 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_biz counter if T_0==1 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout19_asp_bizl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_biz) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///									
				(bar varsout19_asp_fam counter if T_0==0 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_fam counter if T_0==1 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout19_asp_faml counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_fam) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout19_asp_job ubout19_asp_job counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_biz ubout19_asp_biz counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_fam ubout19_asp_fam counter if T_0 == 1,  lcolor(black)), ///	 ///
/*
			   xalternate yalternate */ ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(1.5 "Job" 4 "Business" 6.5 "Family") 		///
			   $TwowayBar
			   
			 graph export "$applicant_mast/Outputs/Figures/aspirations_women.png", replace
			 
			 
**Subsample: Men

version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

keep if gender_app == 1
	
	
/*
	* Specify variables
	gen vars_control = .
	gen vars_treat = .
	gen vars = .
	gen lb = .
	gen ub = .
	gen pval = .
*/
	
	* Set local
	local educ_cat out19_asp_job out19_asp_biz out19_asp_fam 
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if _n == 1
				replace vars`var' = vars_treat`var' if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		

		* Create graphable dataset
		use `out19_asp_job', clear
			
		foreach var in out19_asp_biz out19_asp_fam {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") /* if var_T`var' >= 0.015 | var_T`var' <= -0.015
*/
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout19_asp_job counter if T_0==0 /* & var_name == "out19_asp_job" */, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_job counter if T_0==1 /* & var_name == "out19_asp_job" */, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///
					(scatter varsout19_asp_jobl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_job) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout19_asp_biz counter if T_0==0 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_biz counter if T_0==1 /* & var_name == "out19_asp_biz" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout19_asp_bizl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_biz) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///									
				(bar varsout19_asp_fam counter if T_0==0 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout19_asp_fam counter if T_0==1 /* & var_name == "out19_asp_fam" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout19_asp_faml counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout19_asp_fam) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout19_asp_job ubout19_asp_job counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_biz ubout19_asp_biz counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout19_asp_fam ubout19_asp_fam counter if T_0 == 1,  lcolor(black)), ///	 ///
/*
			   xalternate yalternate */ ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(1.5 "Job" 4 "Business" 6.5 "Family") 		///
			   $TwowayBar
			   
			 graph export "$applicant_mast/Outputs/Figures/aspirations_men.png", replace			 