
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Output/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1
	
	
/*
	* Specify variables
	gen vars_control = .
	gen vars_treat = .
	gen vars = .
	gen lb = .
	gen ub = .
	gen pval = .
*/
	
	* Set local
	local educ_cat out6_educ_low out6_educ_sen out6_educ_ter out6_educ_cert out6_educ_dip
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if _n == 1
				replace vars`var' = vars_treat`var' if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		

		* Create graphable dataset
		use `out6_educ_low', clear
			
		foreach var in out6_educ_sen out6_educ_ter out6_educ_cert out6_educ_dip {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout6_educ_low counter if T_0==0 /* & var_name == "out6_educ_low" */, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_low counter if T_0==1 /* & var_name == "out6_educ_low" */, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///
					(scatter varsout6_educ_lowl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_low) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_educ_sen counter if T_0==0 /* & var_name == "out6_educ_sen" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_sen counter if T_0==1 /* & var_name == "out6_educ_sen" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_senl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_sen) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///									
				(bar varsout6_educ_ter counter if T_0==0 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_ter counter if T_0==1 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout6_educ_terl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_ter) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_educ_cert counter if T_0==0 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_cert counter if T_0==1 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout6_educ_certl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_cert) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_educ_dip counter if T_0==0 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_dip counter if T_0==1 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_dipl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_dip) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout6_educ_low ubout6_educ_low counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_sen ubout6_educ_sen counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_ter ubout6_educ_ter counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_cert ubout6_educ_cert counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_dip ubout6_educ_dip counter if T_0 == 1,  lcolor(black)), ///	 ///
/*
			   xalternate yalternate */ ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 0.6)																///
			   xlabel(1.5 `" "Lower" "Secondary" "' 4 `" "Senior" "Secondary" "' 6.5 `" "Any" "Tertiary" "' 9 "Certificate" 11.5 "Diploma") 		///
			   $TwowayBar
			   
			 graph export "$applicant_mast/Outputs/Figures/education_3_levels.png", replace
	
	
	
/*	
	* Set local
	local educ_cat out6_educ_low out6_educ_sen out6_educ_ter
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 0
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control if _n == 1
				replace vars`var' = vars_treat if _n == 2
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		

		* Create graphable dataset
		use `out6_educ_low', clear
			
		foreach var in out6_educ_sen out6_educ_ter {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$do/GraphFormatting.do"
		
		* Set order
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		replace counter = 3.5 if _n == 3
		replace counter = 4.5 if _n == 4
		replace counter = 6 if _n == 5
		replace counter = 7 if _n == 6
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(vars`var', "%3.2f")
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout6_educ_low counter if T_0==0 /* & var_name == "out6_educ_low" */, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_low counter if T_0==1 /* & var_name == "out6_educ_low" */, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) 				///					
				(bar varsout6_educ_sen counter if T_0==0 /* & var_name == "out6_educ_sen" */, 			///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_sen counter if T_0==1 /* & var_name == "out6_educ_sen" */, 			///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///									
				(bar varsout6_educ_ter counter if T_0==0 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_ter counter if T_0==1 /* & var_name == "out6_educ_ter" */, 			///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)), ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 1)																///
			   xlabel(1.5 "Lower Secondary" 4 "Senior Secondary" 6.5 "Any Tertiary") 																///
			   $TwowayBar
			   
			 graph export "$output/Figures/education_3_levels.png", replace