
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Output/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata

pause on

**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1
*replace out6_incomePPP_22 = . if out6_incomePPP_22 == 0

gen out6_incomePPP_22_L = out6_incomePPP_22 if out6_educ_low == 1 
gen out6_incomePPP_22_S = out6_incomePPP_22 if out6_educ_sen == 1 
gen out6_incomePPP_22_T = out6_incomePPP_22 if out6_educ_ter == 1 
gen out6_incomePPP_22_C = out6_incomePPP_22 if out6_educ_cert == 1 
gen out6_incomePPP_22_D = out6_incomePPP_22 if out6_educ_dip == 1 


local income_vars out6_incomePPP_22_L out6_incomePPP_22_S out6_incomePPP_22_T out6_incomePPP_22_C out6_incomePPP_22_D

	
	foreach var in `income_vars'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 /* i.NSC_intdcode */ cohort2014 sex_app /* survey_year_a */, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control`var' = `controlMean' if T_0 == 0
				gen vars_treat`var' = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if _n == 1
				replace vars`var' = vars_treat`var' if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}


		* Create graphable dataset
		use `out6_incomePPP_22_L', clear
			
		foreach var in out6_incomePPP_22_S out6_incomePPP_22_T out6_incomePPP_22_C out6_incomePPP_22_D {
			append using "``var''" 
		}

* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"Average monthly income"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `income_vars''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}


		foreach var in `income_vars'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}


		* Plot bar graph
		twoway 	(bar varsout6_incomePPP_22_L counter if T_0==0 , 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_incomePPP_22_L counter if T_0==1 , 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///		
					(scatter varsout6_incomePPP_22_Ll counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_incomePPP_22_L) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_incomePPP_22_S counter if T_0==0 , 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_incomePPP_22_S counter if T_0==1 , 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///	
					(scatter varsout6_incomePPP_22_Sl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_incomePPP_22_S) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_incomePPP_22_T counter if T_0==0 , 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_incomePPP_22_T counter if T_0==1 , 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout6_incomePPP_22_Tl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_incomePPP_22_T) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_incomePPP_22_C counter if T_0==0 , 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_incomePPP_22_C counter if T_0==1 , 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout6_incomePPP_22_Cl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_incomePPP_22_C) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(bar varsout6_incomePPP_22_D counter if T_0==0 , 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_incomePPP_22_D counter if T_0==1 , 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_incomePPP_22_Dl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_incomePPP_22_D) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout6_incomePPP_22_L ubout6_incomePPP_22_L counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_incomePPP_22_S ubout6_incomePPP_22_S counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_incomePPP_22_T ubout6_incomePPP_22_T counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_incomePPP_22_C ubout6_incomePPP_22_C counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_incomePPP_22_D ubout6_incomePPP_22_D counter if T_0 == 1,  lcolor(black)), ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(-100 (100) 300)																///
			   xlabel(1.5 `" "Lower" "Secondary" "' 4 `" "Senior" "Secondary" "' 6.5 `" "Any" "Tertiary" "' 9 "Certificate" 11.5 "Diploma") 																///
			   $TwowayBar

*graph export "$applicant_mast/Outputs/Figures/education_3_levels_pay.png", replace

graph export "$applicant_mast/Outputs/Figures/education_3_levels_pay_noFE.png", replace   // without district and survey_year FE

