
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2024													*
*Author:		Raaga Akkineni 												*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

do "$mastdata_do_ap/Figures/GraphFormatting.do" 

**Setting scheme
set scheme tab1 

**Use of time
local time_vars out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep

label define T_0 0 "Control" 1 "Treatment"
label value T_0 T_0



/*
graph bar `time_vars', over(T_0) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use.png", replace



graph bar `time_vars', over(T_0) over(gender_app) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use_gender.png", replace
*/


local educ_cat out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME

keep if gender_app == 1 			// Subsample: Men

	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
								
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen `var'_o = .
				collapse (firstnm) `var' vars_control vars_treat `var'_o lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace `var'_o = vars_control if _n == 1
				replace `var'_o = vars_treat if _n == 2
				
				* Var for scatter plot
				gen `var'_ol = `var'_o + (ub`var'-`var'_o)
				
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `out6_time_study_ME', clear

		* Create graphable dataset	
		foreach var in out6_time_work_ME out6_time_both_ME out6_time_neither_ME{
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05 
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar out6_time_study_ME_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar out6_time_study_ME_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
/*
					(scatter out6_time_study_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_study_ME) mlabposition(12) mlabcolor(black))  */	///
					(scatter out6_time_study_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_study_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_work_ME_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_work_ME_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter out6_time_work_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_work_ME) mlabposition(12) mlabcolor(black))  */	///
					(scatter out6_time_work_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_work_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_both_ME_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_both_ME_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter out6_time_both_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_both_ME) mlabposition(12) mlabcolor(black))  */	///
					(scatter out6_time_both_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_both_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_neither_ME_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_neither_ME_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
/*
					(scatter out6_time_neither_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_neither_ME) mlabposition(12) mlabcolor(black))  */		///
					(scatter out6_time_neither_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_neither_ME) mlabposition(12) mlabcolor(black))		///
					///
///
				(rcap lbout6_time_study_ME ubout6_time_study_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_work_ME ubout6_time_work_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_both_ME ubout6_time_both_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_neither_ME ubout6_time_neither_ME counter if T_0 == 1,  lcolor(black)), ///
 ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 0.7)																///
			   xlabel(1.5 "School" 4 "Work" 6.5 "Both" 9 "Neither", labsize(vsmall)) 																///
			   $TwowayBar name(edu_work_split_men_12mths) title(Men)
			   
			    *graph export "$applicant_mast/Outputs/Figures/education_work_split_men_12mths.png", replace


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

do "$mastdata_do_ap/Figures/GraphFormatting.do" 

**Setting scheme
set scheme tab1 

**Use of time
local time_vars out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep

label define T_0 0 "Control" 1 "Treatment"
label value T_0 T_0



/*
graph bar `time_vars', over(T_0) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use.png", replace



graph bar `time_vars', over(T_0) over(gender_app) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use_gender.png", replace
*/


local educ_cat out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME				
				
				
keep if gender_app == 0			// Subsample: Women		

	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen `var'_o = .
				collapse (firstnm) `var' vars_control vars_treat `var'_o lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace `var'_o = vars_control if _n == 1
				replace `var'_o = vars_treat if _n == 2
				
				* Var for scatter plot
				gen `var'_ol = `var'_o + (ub`var'-`var'_o)
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `out6_time_study_ME', clear

		* Create graphable dataset	
		foreach var in out6_time_work_ME out6_time_both_ME out6_time_neither_ME{
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") /* if var_T`var' >= 0.015 | var_T`var' <= -0.015
*/
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05 
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar out6_time_study_ME_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar out6_time_study_ME_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
/*
					(scatter out6_time_study_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_study_ME) mlabposition(12) mlabcolor(black)) */ 	///
					(scatter out6_time_study_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_study_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_work_ME_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_work_ME_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter out6_time_work_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_work_ME) mlabposition(12) mlabcolor(black)) */ 	///
					(scatter out6_time_work_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_work_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_both_ME_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_both_ME_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter out6_time_both_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_both_ME) mlabposition(12) mlabcolor(black)) 	 */ ///
					(scatter out6_time_both_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_both_ME) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar out6_time_neither_ME_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar out6_time_neither_ME_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
/*
					(scatter out6_time_neither_ME_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundout6_time_neither_ME) mlabposition(12) mlabcolor(black)) */ 		///
					(scatter out6_time_neither_ME_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_time_neither_ME) mlabposition(12) mlabcolor(black)) 		///
					///
///
				(rcap lbout6_time_study_ME ubout6_time_study_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_work_ME ubout6_time_work_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_both_ME ubout6_time_both_ME counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_time_neither_ME ubout6_time_neither_ME counter if T_0 == 1,  lcolor(black)), ///
 ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 0.7)																///
			   xlabel(1.5 "School" 4 "Work" 6.5 "Both" 9 "Neither", labsize(vsmall)) 																///
			   $TwowayBar name(edu_work_split_women_12mths) title(Women)
			   
			    *graph export "$applicant_mast/Outputs/Figures/education_work_split_women_12mths.png", replace

				   grc1leg2 	edu_work_split_men_12mths edu_work_split_women_12mths, xcommon ycommon
 			    graph export "$applicant_mast/Outputs/Figures/education_work_split_both_12mths.png", replace
