
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2024													*
*Author:		Raaga Akkineni												*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*		*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1
	
	
/*
	* Specify variables
	gen vars_control = .
	gen vars_treat = .
	gen vars = .
	gen lb = .
	gen ub = .
	gen pval = .
*/
	
	* Set local
	local educ_cat out6_educ_S1 out6_educ_S2 out6_educ_S3 out6_educ_S4 out6_educ_S5 out6_educ_S6 /* out6_educ_attter */ out6_educ_cert out6_educ_dip /* out6_educ_comter
*/
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 sex_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control vars_treat vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control if _n == 1
				replace vars`var' = vars_treat if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
				
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `out6_educ_S1', clear

		* Create graphable dataset	
		foreach var in out6_educ_S2 out6_educ_S3 out6_educ_S4 out6_educ_S5 out6_educ_S6 /* out6_educ_attter */ out6_educ_cert out6_educ_dip /* out6_educ_comter */ {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") /* if var_T`var' >= 0.015 | var_T`var' <= -0.015
*/
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout6_educ_S1 counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar varsout6_educ_S1 counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
					(scatter varsout6_educ_S1l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S1) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_S2 counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_S2 counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_S2l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S2) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///out6_incomePPP_22_L
				(bar varsout6_educ_S3 counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_S3 counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_S3l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S3) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_S4 counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_S4 counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
					(scatter varsout6_educ_S4l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S4) mlabs(vsmall) mlabposition(12) mlabgap(0.5) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_S5 counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_S5 counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_S5l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S5) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_S6 counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_S6 counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_S6l counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_S6) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_cert counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_cert counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_certl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_cert) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_dip counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_dip counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_dipl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_dip) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///	
					///
/*
				(bar varsout6_educ_attter counter if T_0==0, 			///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_attter counter if T_0==1, 			///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_attter counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_attter) mlabposition(0) mlabcolor(black)) 		///
					///
				(bar varsout6_educ_comter counter if T_0==0, 			///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar varsout6_educ_comter counter if T_0==1, 			///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///
					(scatter varsout6_educ_comter counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout6_educ_comter) mlabposition(0) mlabcolor(black)) 		///
 */ ///
///
				(rcap lbout6_educ_S1 ubout6_educ_S1 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_S2 ubout6_educ_S2 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_S3 ubout6_educ_S3 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_S4 ubout6_educ_S4 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_S5 ubout6_educ_S5 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_S6 ubout6_educ_S6 counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_cert ubout6_educ_cert counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_dip ubout6_educ_dip counter if T_0 == 1,  lcolor(black)), ///
/*
				(rcap lbout6_educ_attter ubout6_educ_attter counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout6_educ_comter ubout6_educ_comter counter if T_0 == 1,  lcolor(black)), ///
 */ ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 0.6)																///
			   xlabel(1.5 "S1" 4 "S2" 6.5 "S3" 9 "S4" 11.5 "S5" 14 "S6" 16.5 "Certificate" 19 "Diploma" /* 21.5 "Attended Tertiary" 24 "Completed Tertiary" */, labsize(vsmall)) 																///
			   $TwowayBar
			   
		 graph export "$applicant_mast/Outputs/Figures/education_ind_levels_CI.png", replace