/*---------------------------------------------------------------------------*
*Description: 	Generate coefplots for main outcomes						*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*
*Input:			Cohort_2014_2015_StandardizedDataset.dta					*
*				Cohort2014_2015_Data_ForTables.dta							*
*Output:		Edu_outcomes_2Y_Followup.png	(not used in paper)			*
*Note: 																		*
*---------------------------------------------------------------------------*/

version 13
set more off

clear all
clear mata

set seed 20200516
pause on


global cohortFE cohort2014
global districtFE i.NSC_intdcode


	use "$caregiver_enc/data/Cohort_2014_2015_StandardizedDataset.dta", clear
	
	merge m:1 id_new baseline using "$attrition_mast/Data/Cohort2014_2015_Data_ForTables.dta", nogen
/* 
	 Result                      Number of obs
    -----------------------------------------
    Not matched                             0
    Matched                             4,184  
    -----------------------------------------
*/

	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1 /* (662 observations deleted)*/
	
	*** Define Regressors
		
	sum out1_uceaggregate if baseline == 0 & T_0 == 0, d 
		
	gen out1_uceaggregate_Z = -1*((out1_uceaggregate - r(mean)) / r(sd)) 

	rename out1_appenrolled_fu out1_appenrolled
	
	gen out1_passuce = .
	recode out1_passuce (. = 1) if out1_uceaggregate < 60
	recode out1_passuce (. = 0) if out1_uceaggregate >= 60 & out1_uceaggregate != .
	

**Outcomes
local educ_cat out1_appenrolled out0_appwork 

foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode sex_app cohort2014 if notfoundatFU == 0, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control vars_treat vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control if _n == 1
				replace vars`var' = vars_treat if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
				
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `out1_appenrolled', clear

		* Create graphable dataset	
		foreach var in  out0_appwork  {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_cg/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout1_appenrolled counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar varsout1_appenrolled counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
					(scatter varsout1_appenrolledl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_appenrolled) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout0_appwork counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout0_appwork counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout0_appworkl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout0_appwork) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
				(rcap lbout1_appenrolled ubout1_appenrolled counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout0_appwork ubout0_appwork counter if T_0 == 1,  lcolor(black)) , ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(1.5 "Enrollment" 4 "Applicant works",  labsize(vsmall)) 																///
			   $TwowayBar
			  
			   
			   graph export "$caregiver_mast/Outputs/Figures/Edu_outcomes_2Y_Followup.png", replace