/*---------------------------------------------------------------------------*
*Description: 	Generate education outcome tables							*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*
*Input:			LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta			*
*																			*
*Output:		table_balance_all_eligibles_FU.tex						    *
*				table_balance_all_eligibles_LTFU.tex (not in paper)	  	    *
*				table_balance_attrition_FU.tex 							    *
*				table_balance_attrition_LTFU.tex 							*
*Note: 																		*
*---------------------------------------------------------------------------*/

clear all
clear mata

set seed 20200516
pause on

set scheme sj

global cohortFE cohort2014
global districtFE i.NSC_intdcode
	
		
	*do "Data - Analysis/Code/Cohort_2014_2015_DatasetCreation_ForTables.do"
	
	use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data_deid.dta", clear

	
	*** Sample

	keep if baseline == 1 /*(3,522 observations deleted)*/
	
	keep if final_select == 1 /*(662 observations deleted)*/
	
	keep if notfoundatFU != . /*(4 observations deleted)*/
	
	keep if NSC_intdcode != . /*(1 observation1 deleted)*/


* Relabel variables 

gen C_0 = (T_0 == 0) /* To calculate "Correct" Normalized Difference*/

lab var out0_hhno_b "Household Size"

/*
lab var out0_motherage_b "Mother's Age" 

lab var out0_motheredu_b "Mother's Years of Schooling"

lab var out0_fatherage_b "Father's Age" 

lab var out0_fatheredu_b "Father's Years of Schooling"
*/

lab var out0_caregiverage_b "Caregiver's Age" 

lab var out0_caregiveredu_b "Caregiver's Years of Schooling"

lab var out0_dependents_b "Number of Dependents"

lab var out0_appwork_b "Applicant Works"

lab var out0_hhbrac_b "BRAC Beneficiary"

lab var out1_totallchild6_18_b "Children of Schooling Age"

lab var out4_totincomePPP_2022_b "Labor Income"

lab var out4_savingsvaluePPP_2022_b "Cash Savings"

lab var out5_expendituresPPP_2022_b "Consumption"

lab var out4_totalassetPPP_2022_b "Assets Value"

lab var out6_nonagribusiness2_b "Owns Non-Agri Business"

lab var /* out0_povscore09_c_b */ out0_povscore09_c_b "Poverty Score"

lab var out4_thatchroof_b "Home Has Thatch Roof"


* Fixed effects
global cohortFE cohort2014
global districtFE i.NSC_intdcode

local covariates out0_povscore09_c_b out0_hhno_b out0_caregiverage_b out0_caregiveredu_b out0_dependents_b out1_totallchild6_18_b out4_totincomePPP_2022_b out4_savingsvaluePPP_2022_b out5_expendituresPPP_2022_b out4_totalassetPPP_2022_b out6_nonagribusiness2_b  out4_thatchroof_b out0_appwork_b out0_hhbrac_b

keep  T_0 C_0 NSC_intdcode sex_app cohort2014 notfoundatFU notfoundatLTFU `covariates'


local i = 0			


// Balance Tables for Treatment groups for those found at LTFU


	local destinationfile "$caregiver_mast/Outputs/Tables/Balance Tables/table_balance_all_eligibles.tex" 
	
	preserve 
	
	di `i'
	
	if `i' == 1 {  
		keep if notfoundatFU == 0
	}
	
	tempname postBalance
	tempfile balance
	postfile `postBalance' line str100 Variable ControlMeans DiffGroup2 str5 Stars2 NormDiff Observations using "`balance'", replace

	/* Loop on variables to build each line of the table */
foreach x of local covariates {
    
	local variable: var label `x'
	
	/* Mean and SD of control group */
	qui sum `x' if T_0 == 0
	local control_mean = r(mean)
	local control_sd = r(sd)

	/* Coefficients, SE and significance stars for groups 2 and 3 */
	qui reg `x' T_0 $districtFE sex_app $cohortFE
	local obs=e(N)
	
	qui test T_0
	local teststat2=r(F)
	local stars2
	if r(p) < 0.10 local stars2 "*"
	if r(p) < 0.05 local stars2 "**"
	if r(p) < 0.01 local stars2 "***"
	
	/* Standardized Difference */
	stddiff `x', by(C_0)
	local normdiff = r(stddiff)[1,1]

	/* Post values computed so far (first 2 lines) */
	post `postBalance' (1) ("`variable'") 	(`control_mean') 	(_b[T_0]) 	("") 			(`normdiff')	(`obs')
	post `postBalance' (2) ("") 			(`control_sd') 		(_se[T_0]) 	("`stars2'")  	(.)				(.)
	
	}
	postclose `postBalance'

/* Edit table content (add parentheses, significance stars, ect...) */
	use `balance', clear

	tostring ControlMeans DiffGroup2 NormDiff, replace force format(%10.3fc)

	tostring Observations, replace force format(%10.0fc)

	replace ControlMeans 	= "\scriptsize{("+ControlMeans+")}" if line == 2

	replace DiffGroup2 		= "\scriptsize{("+DiffGroup2+")}"+Stars2 if line == 2

	foreach z in ControlMeans DiffGroup2 NormDiff Observations {
		
		replace `z' = "" if `z' == "."
		
	}

		replace Observations = "\medskip" if line == 2

/* Print the table */

	listtab Variable ControlMeans DiffGroup2 NormDiff Observations using "`destinationfile'", rstyle(tabular) replace 

	restore

	local ++i


	
 
/*

**Only Long term follow up results (not in the paper)

// Balance Tables for Treatment groups for those found at LTFU
preserve 

local destinationfile "$caregiver_mast/Outputs/Tables/Balance Tables/table_balance_all_eligibles_LTFU.tex" 
	
	di `i'
	
	if `i' == 1 {  
		keep if notfoundatLTFU == 0
	}
	
	tempname postBalance
	tempfile balance
	postfile `postBalance' line str100 Variable ControlMeans DiffGroup2 str5 Stars2 NormDiff Observations using "`balance'", replace

	/* Loop on variables to build each line of the table */
foreach x of local covariates {
    
	local variable: var label `x'
	
	/* Mean and SD of control group */
	qui sum `x' if T_0 == 0
	local control_mean = r(mean)
	local control_sd = r(sd)

	/* Coefficients, SE and significance stars for groups 2 and 3 */
	qui reg `x' T_0 $districtFE sex_app $cohortFE
	local obs=e(N)
	
	qui test T_0
	local teststat2=r(F)
	local stars2
	if r(p) < 0.10 local stars2 "*"
	if r(p) < 0.05 local stars2 "**"
	if r(p) < 0.01 local stars2 "***"
	
	/* Standardized Difference */
	stddiff `x', by(C_0)
	local normdiff = r(stddiff)[1,1]

	/* Post values computed so far (first 2 lines) */
	post `postBalance' (1) ("`variable'") 	(`control_mean') 	(_b[T_0]) 	("") 			(`normdiff')	(`obs')
	post `postBalance' (2) ("") 			(`control_sd') 		(_se[T_0]) 	("`stars2'")  	(.)				(.)
	
	}
	postclose `postBalance'

/* Edit table content (add parentheses, significance stars, ect...) */
	use `balance', clear

	tostring ControlMeans DiffGroup2 NormDiff, replace force format(%10.3fc)

	tostring Observations, replace force format(%10.0fc)

	replace ControlMeans 	= "\scriptsize{("+ControlMeans+")}" if line == 2

	replace DiffGroup2 		= "\scriptsize{("+DiffGroup2+")}"+Stars2 if line == 2

	foreach z in ControlMeans DiffGroup2 NormDiff Observations {
		
		replace `z' = "" if `z' == "."
		
	}

		replace Observations = "\medskip" if line == 2

/* Print the table */

	listtab Variable ControlMeans DiffGroup2 NormDiff Observations using "`destinationfile'", rstyle(tabular) replace 

	restore
*/


// Balance Tables for Attriters and non-attriters at Follow-up	
	preserve 

local destinationfile "$caregiver_mast/Outputs/Tables/Balance Tables/table_balance_attrition_FU.tex" 
	
	di `i'
	
	if `i' == 1 {  
		keep if notfoundatFU != .
	}
	
	tempname postBalance
	tempfile balance
	postfile `postBalance' line str100 Variable ControlMeans DiffGroup2 str5 Stars2 NormDiff Observations using "`balance'", replace

	/* Loop on variables to build each line of the table */
foreach x of local covariates {
    
	local variable: var label `x'
	
	/* Mean and SD of control group */
	qui sum `x' if notfoundatFU == 0
	local control_mean = r(mean)
	local control_sd = r(sd)

	/* Coefficients, SE and significance stars for groups 2 and 3 */
	qui reg `x' notfoundatFU $districtFE sex_app $cohortFE
	local obs=e(N)
	
	qui test notfoundatFU
	local teststat2=r(F)
	local stars2
	if r(p) < 0.10 local stars2 "*"
	if r(p) < 0.05 local stars2 "**"
	if r(p) < 0.01 local stars2 "***"
	
	
	/* Standardized Difference */
	stddiff `x', by(notfoundatFU) 
	local normdiff = r(stddiff)[1,1]

	/* Post values computed so far (first 2 lines) */
	post `postBalance' (1) ("`variable'") 	(`control_mean') 	(_b[notfoundatFU]) 	("") 			(`normdiff')	(`obs')
	post `postBalance' (2) ("") 			(`control_sd') 		(_se[notfoundatFU]) 	("`stars2'")  	(.)				(.)
	
	}
	postclose `postBalance'

/* Edit table content (add parentheses, significance stars, ect...) */
	use `balance', clear

	tostring ControlMeans DiffGroup2 NormDiff, replace force format(%10.3fc)

	tostring Observations, replace force format(%10.0fc)

	replace ControlMeans 	= "\scriptsize{("+ControlMeans+")}" if line == 2

	replace DiffGroup2 		= "\scriptsize{("+DiffGroup2+")}"+Stars2 if line == 2

	foreach z in ControlMeans DiffGroup2 NormDiff Observations {
		
		replace `z' = "" if `z' == "."
		
	}

		replace Observations = "\medskip" if line == 2

/* Print the table */

	listtab Variable ControlMeans DiffGroup2 NormDiff Observations using "`destinationfile'", rstyle(tabular) replace 

	restore
	


	
// Balance Tables for Attriters and non-attriters at LTFU	
	preserve  

local destinationfile "$caregiver_mast/Outputs/Tables/Balance Tables/table_balance_attrition_LTFU.tex" 
	
	di `i'
	
	if `i' == 1 {  
		keep if notfoundatFU != .
	}
	
	tempname postBalance
	tempfile balance
	postfile `postBalance' line str100 Variable ControlMeans DiffGroup2 str5 Stars2 NormDiff Observations using "`balance'", replace

	/* Loop on variables to build each line of the table */
foreach x of local covariates {
    
	local variable: var label `x'
	
	/* Mean and SD of control group */
	qui sum `x' if notfoundatLTFU == 0
	local control_mean = r(mean)
	local control_sd = r(sd)

	/* Coefficients, SE and significance stars for groups 2 and 3 */
	qui reg `x' notfoundatLTFU $districtFE sex_app $cohortFE
	local obs=e(N)
	
	qui test notfoundatLTFU
	local teststat2=r(F)
	local stars2
	if r(p) < 0.10 local stars2 "*"
	if r(p) < 0.05 local stars2 "**"
	if r(p) < 0.01 local stars2 "***"
	
	
	/* Standardized Difference */
	stddiff `x', by(notfoundatLTFU) 
	local normdiff = r(stddiff)[1,1]

	/* Post values computed so far (first 2 lines) */
	post `postBalance' (1) ("`variable'") 	(`control_mean') 	(_b[notfoundatLTFU]) 	("") 			(`normdiff')	(`obs')
	post `postBalance' (2) ("") 			(`control_sd') 		(_se[notfoundatLTFU]) 	("`stars2'")  	(.)				(.)
	
	}
	postclose `postBalance'

/* Edit table content (add parentheses, significance stars, ect...) */
	use `balance', clear

	tostring ControlMeans DiffGroup2 NormDiff, replace force format(%10.3fc)

	tostring Observations, replace force format(%10.0fc)

	replace ControlMeans 	= "\scriptsize{("+ControlMeans+")}" if line == 2

	replace DiffGroup2 		= "\scriptsize{("+DiffGroup2+")}"+Stars2 if line == 2

	foreach z in ControlMeans DiffGroup2 NormDiff Observations {
		
		replace `z' = "" if `z' == "."
		
	}

		replace Observations = "\medskip" if line == 2

/* Print the table */

	listtab Variable ControlMeans DiffGroup2 NormDiff Observations using "`destinationfile'", rstyle(tabular) replace 

	restore
	
*/
